
-----------------------------------------------------------------------------
-- KSAP_ATP
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSAP_ATP';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSAP_ATP CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSAP_ATP
(
      ID VARCHAR2(255)
        , CREATEID VARCHAR2(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR2(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR NUMBER(19) NOT NULL
        , END_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , START_DT TIMESTAMP
        , STATE VARCHAR2(255)
        , RT_DESCR_ID VARCHAR2(255)
        , TYPE VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
    

)
/

ALTER TABLE KSAP_ATP
    ADD CONSTRAINT KSAP_ATPP1
PRIMARY KEY (ID)
/


CREATE INDEX KSAP_ATP_I1 
  ON KSAP_ATP 
  (TYPE)
/
CREATE INDEX KSAP_ATP_I2 
  ON KSAP_ATP 
  (RT_DESCR_ID)
/





-----------------------------------------------------------------------------
-- KSAP_ATP_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSAP_ATP_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSAP_ATP_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSAP_ATP_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSAP_ATP_ATTR
    ADD CONSTRAINT KSAP_ATP_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSAP_ATP_ATTR_I1 
  ON KSAP_ATP_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSAP_ATP_DUR_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSAP_ATP_DUR_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSAP_ATP_DUR_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSAP_ATP_DUR_TYPE
(
      TYPE_KEY VARCHAR2(255)
        , TYPE_DESC VARCHAR2(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSAP_ATP_DUR_TYPE
    ADD CONSTRAINT KSAP_ATP_DUR_TYPEP1
PRIMARY KEY (TYPE_KEY)
/







-----------------------------------------------------------------------------
-- KSAP_ATP_DUR_TYPE_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSAP_ATP_DUR_TYPE_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSAP_ATP_DUR_TYPE_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSAP_ATP_DUR_TYPE_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSAP_ATP_DUR_TYPE_ATTR
    ADD CONSTRAINT KSAP_ATP_DUR_TYPE_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSAP_ATP_DUR_TYPE_ATTR_I1 
  ON KSAP_ATP_DUR_TYPE_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSAP_ATP_SEASONAL_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSAP_ATP_SEASONAL_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSAP_ATP_SEASONAL_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSAP_ATP_SEASONAL_TYPE
(
      TYPE_KEY VARCHAR2(255)
        , TYPE_DESC VARCHAR2(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSAP_ATP_SEASONAL_TYPE
    ADD CONSTRAINT KSAP_ATP_SEASONAL_TYPEP1
PRIMARY KEY (TYPE_KEY)
/







-----------------------------------------------------------------------------
-- KSAP_ATP_SEASONAL_TYPE_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSAP_ATP_SEASONAL_TYPE_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSAP_ATP_SEASONAL_TYPE_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSAP_ATP_SEASONAL_TYPE_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSAP_ATP_SEASONAL_TYPE_ATTR
    ADD CONSTRAINT KSAP_ATP_SEASONAL_TYPE_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSAP_ATP_SEAS_TYPE_ATTR_I1 
  ON KSAP_ATP_SEASONAL_TYPE_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSAP_ATP_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSAP_ATP_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSAP_ATP_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSAP_ATP_TYPE
(
      TYPE_KEY VARCHAR2(255)
        , TYPE_DESC VARCHAR2(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , DUR_TYPE VARCHAR2(255)
        , SEASONAL_TYPE VARCHAR2(255)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSAP_ATP_TYPE
    ADD CONSTRAINT KSAP_ATP_TYPEP1
PRIMARY KEY (TYPE_KEY)
/


CREATE INDEX KSAP_ATP_TYPE_I1 
  ON KSAP_ATP_TYPE 
  (SEASONAL_TYPE)
/
CREATE INDEX KSAP_ATP_TYPE_I2 
  ON KSAP_ATP_TYPE 
  (DUR_TYPE)
/





-----------------------------------------------------------------------------
-- KSAP_ATP_TYPE_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSAP_ATP_TYPE_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSAP_ATP_TYPE_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSAP_ATP_TYPE_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSAP_ATP_TYPE_ATTR
    ADD CONSTRAINT KSAP_ATP_TYPE_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSAP_ATP_TYPE_ATTR_I1 
  ON KSAP_ATP_TYPE_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSAP_DT_RANGE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSAP_DT_RANGE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSAP_DT_RANGE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSAP_DT_RANGE
(
      DATERANGE_KEY VARCHAR2(255)
        , CREATEID VARCHAR2(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR2(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR NUMBER(19) NOT NULL
        , END_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , START_DT TIMESTAMP
        , STATE VARCHAR2(255)
        , ATP_ID VARCHAR2(255)
        , RT_DESCR_ID VARCHAR2(255)
        , DT_RANGE_TYPE_ID VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
    

)
/

ALTER TABLE KSAP_DT_RANGE
    ADD CONSTRAINT KSAP_DT_RANGEP1
PRIMARY KEY (DATERANGE_KEY)
/


CREATE INDEX KSAP_DT_RANGE_I1 
  ON KSAP_DT_RANGE 
  (DT_RANGE_TYPE_ID)
/
CREATE INDEX KSAP_DT_RANGE_I2 
  ON KSAP_DT_RANGE 
  (RT_DESCR_ID)
/
CREATE INDEX KSAP_DT_RANGE_I3 
  ON KSAP_DT_RANGE 
  (ATP_ID)
/





-----------------------------------------------------------------------------
-- KSAP_DT_RANGE_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSAP_DT_RANGE_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSAP_DT_RANGE_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSAP_DT_RANGE_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSAP_DT_RANGE_ATTR
    ADD CONSTRAINT KSAP_DT_RANGE_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSAP_DT_RANGE_ATTR_I1 
  ON KSAP_DT_RANGE_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSAP_DT_RANGE_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSAP_DT_RANGE_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSAP_DT_RANGE_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSAP_DT_RANGE_TYPE
(
      TYPE_KEY VARCHAR2(255)
        , TYPE_DESC VARCHAR2(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSAP_DT_RANGE_TYPE
    ADD CONSTRAINT KSAP_DT_RANGE_TYPEP1
PRIMARY KEY (TYPE_KEY)
/







-----------------------------------------------------------------------------
-- KSAP_DT_RANGE_TYPE_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSAP_DT_RANGE_TYPE_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSAP_DT_RANGE_TYPE_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSAP_DT_RANGE_TYPE_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSAP_DT_RANGE_TYPE_ATTR
    ADD CONSTRAINT KSAP_DT_RANGE_TYPE_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSAP_DT_RANGE_TYPE_ATTR_I1 
  ON KSAP_DT_RANGE_TYPE_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSAP_MLSTN
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSAP_MLSTN';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSAP_MLSTN CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSAP_MLSTN
(
      ID VARCHAR2(255)
        , CREATEID VARCHAR2(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR2(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR NUMBER(19) NOT NULL
        , MLSTN_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , STATE VARCHAR2(255)
        , ATP_ID VARCHAR2(255)
        , RT_DESCR_ID VARCHAR2(255)
        , MLSTN_TYPE_ID VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
    

)
/

ALTER TABLE KSAP_MLSTN
    ADD CONSTRAINT KSAP_MLSTNP1
PRIMARY KEY (ID)
/


CREATE INDEX KSAP_MLSTN_I1 
  ON KSAP_MLSTN 
  (ATP_ID)
/
CREATE INDEX KSAP_MLSTN_I2 
  ON KSAP_MLSTN 
  (RT_DESCR_ID)
/
CREATE INDEX KSAP_MLSTN_I3 
  ON KSAP_MLSTN 
  (MLSTN_TYPE_ID)
/





-----------------------------------------------------------------------------
-- KSAP_MLSTN_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSAP_MLSTN_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSAP_MLSTN_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSAP_MLSTN_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSAP_MLSTN_ATTR
    ADD CONSTRAINT KSAP_MLSTN_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSAP_MLSTN_ATTR_I1 
  ON KSAP_MLSTN_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSAP_MLSTN_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSAP_MLSTN_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSAP_MLSTN_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSAP_MLSTN_TYPE
(
      TYPE_KEY VARCHAR2(255)
        , TYPE_DESC VARCHAR2(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSAP_MLSTN_TYPE
    ADD CONSTRAINT KSAP_MLSTN_TYPEP1
PRIMARY KEY (TYPE_KEY)
/







-----------------------------------------------------------------------------
-- KSAP_MLSTN_TYPE_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSAP_MLSTN_TYPE_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSAP_MLSTN_TYPE_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSAP_MLSTN_TYPE_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSAP_MLSTN_TYPE_ATTR
    ADD CONSTRAINT KSAP_MLSTN_TYPE_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSAP_MLSTN_TYPE_ATTR_I1 
  ON KSAP_MLSTN_TYPE_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSAP_RICH_TEXT_T
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSAP_RICH_TEXT_T';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSAP_RICH_TEXT_T CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSAP_RICH_TEXT_T
(
      ID VARCHAR2(255)
        , FORMATTED VARCHAR2(2000)
        , PLAIN VARCHAR2(2000)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSAP_RICH_TEXT_T
    ADD CONSTRAINT KSAP_RICH_TEXT_TP1
PRIMARY KEY (ID)
/







-----------------------------------------------------------------------------
-- KSCO_COMMENT
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSCO_COMMENT';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSCO_COMMENT CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSCO_COMMENT
(
      ID VARCHAR2(255)
        , CREATEID VARCHAR2(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR2(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR NUMBER(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , STATE VARCHAR2(255)
        , RT_DESCR_ID VARCHAR2(255)
        , REFERENCE VARCHAR2(255)
        , TYPE VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
    

)
/

ALTER TABLE KSCO_COMMENT
    ADD CONSTRAINT KSCO_COMMENTP1
PRIMARY KEY (ID)
/


CREATE INDEX KSCO_COMMENT_I1 
  ON KSCO_COMMENT 
  (TYPE)
/
CREATE INDEX KSCO_COMMENT_I2 
  ON KSCO_COMMENT 
  (RT_DESCR_ID)
/
CREATE INDEX KSCO_COMMENT_I3 
  ON KSCO_COMMENT 
  (REFERENCE)
/





-----------------------------------------------------------------------------
-- KSCO_COMMENT_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSCO_COMMENT_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSCO_COMMENT_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSCO_COMMENT_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSCO_COMMENT_ATTR
    ADD CONSTRAINT KSCO_COMMENT_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSCO_COMMENT_ATTR_I1 
  ON KSCO_COMMENT_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSCO_COMMENT_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSCO_COMMENT_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSCO_COMMENT_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSCO_COMMENT_TYPE
(
      TYPE_KEY VARCHAR2(255)
        , TYPE_DESC VARCHAR2(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSCO_COMMENT_TYPE
    ADD CONSTRAINT KSCO_COMMENT_TYPEP1
PRIMARY KEY (TYPE_KEY)
/







-----------------------------------------------------------------------------
-- KSCO_COMMENT_TYPE_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSCO_COMMENT_TYPE_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSCO_COMMENT_TYPE_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSCO_COMMENT_TYPE_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSCO_COMMENT_TYPE_ATTR
    ADD CONSTRAINT KSCO_COMMENT_TYPE_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSCO_COMMENT_TYPE_ATTR_I1 
  ON KSCO_COMMENT_TYPE_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSCO_REFERENCE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSCO_REFERENCE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSCO_REFERENCE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSCO_REFERENCE
(
      ID VARCHAR2(255)
        , REFERENCE_ID VARCHAR2(255)
        , REFERENCE_TYPE VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    
    , CONSTRAINT SYS_C0033779 UNIQUE (REFERENCE_ID, REFERENCE_TYPE)

)
/

ALTER TABLE KSCO_REFERENCE
    ADD CONSTRAINT KSCO_REFERENCEP1
PRIMARY KEY (ID)
/


CREATE INDEX KSCO_REFERENCE_I1 
  ON KSCO_REFERENCE 
  (REFERENCE_TYPE)
/





-----------------------------------------------------------------------------
-- KSCO_REFERENCE_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSCO_REFERENCE_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSCO_REFERENCE_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSCO_REFERENCE_TYPE
(
      TYPE_KEY VARCHAR2(255)
        , TYPE_DESC VARCHAR2(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSCO_REFERENCE_TYPE
    ADD CONSTRAINT KSCO_REFERENCE_TYPEP1
PRIMARY KEY (TYPE_KEY)
/







-----------------------------------------------------------------------------
-- KSCO_REFERENCE_TYPE_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSCO_REFERENCE_TYPE_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSCO_REFERENCE_TYPE_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSCO_REFERENCE_TYPE_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSCO_REFERENCE_TYPE_ATTR
    ADD CONSTRAINT KSCO_REFERENCE_TYPE_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSCO_REFERENCE_TYPE_ATTR_I1 
  ON KSCO_REFERENCE_TYPE_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSCO_RICH_TEXT_T
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSCO_RICH_TEXT_T';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSCO_RICH_TEXT_T CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSCO_RICH_TEXT_T
(
      ID VARCHAR2(255)
        , FORMATTED VARCHAR2(2000)
        , PLAIN VARCHAR2(2000)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSCO_RICH_TEXT_T
    ADD CONSTRAINT KSCO_RICH_TEXT_TP1
PRIMARY KEY (ID)
/







-----------------------------------------------------------------------------
-- KSCO_TAG
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSCO_TAG';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSCO_TAG CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSCO_TAG
(
      ID VARCHAR2(255)
        , CREATEID VARCHAR2(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR2(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR NUMBER(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME_SPACE VARCHAR2(255)
        , PREDICATE VARCHAR2(255)
        , STATE VARCHAR2(255)
        , VAL VARCHAR2(255)
        , REFERENCE VARCHAR2(255)
        , TYPE VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
    

)
/

ALTER TABLE KSCO_TAG
    ADD CONSTRAINT KSCO_TAGP1
PRIMARY KEY (ID)
/


CREATE INDEX KSCO_TAG_I1 
  ON KSCO_TAG 
  (REFERENCE)
/
CREATE INDEX KSCO_TAG_I2 
  ON KSCO_TAG 
  (TYPE)
/





-----------------------------------------------------------------------------
-- KSCO_TAG_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSCO_TAG_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSCO_TAG_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSCO_TAG_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSCO_TAG_ATTR
    ADD CONSTRAINT KSCO_TAG_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSCO_TAG_ATTR_I1 
  ON KSCO_TAG_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSCO_TAG_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSCO_TAG_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSCO_TAG_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSCO_TAG_TYPE
(
      TYPE_KEY VARCHAR2(255)
        , TYPE_DESC VARCHAR2(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSCO_TAG_TYPE
    ADD CONSTRAINT KSCO_TAG_TYPEP1
PRIMARY KEY (TYPE_KEY)
/







-----------------------------------------------------------------------------
-- KSCO_TAG_TYPE_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSCO_TAG_TYPE_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSCO_TAG_TYPE_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSCO_TAG_TYPE_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSCO_TAG_TYPE_ATTR
    ADD CONSTRAINT KSCO_TAG_TYPE_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSCO_TAG_TYPE_ATTR_I1 
  ON KSCO_TAG_TYPE_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSDO_DOCUMENT
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSDO_DOCUMENT';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSDO_DOCUMENT CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSDO_DOCUMENT
(
      DOC_ID VARCHAR2(255)
        , CREATEID VARCHAR2(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR2(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR NUMBER(19) NOT NULL
        , DOCUMENT CLOB
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , FILE_NAME VARCHAR2(255)
        , NAME VARCHAR2(255)
        , STATE VARCHAR2(255)
        , RT_DESCR_ID VARCHAR2(255)
        , TYPE VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
    

)
/

ALTER TABLE KSDO_DOCUMENT
    ADD CONSTRAINT KSDO_DOCUMENTP1
PRIMARY KEY (DOC_ID)
/


CREATE INDEX KSDO_DOCUMENT_I1 
  ON KSDO_DOCUMENT 
  (RT_DESCR_ID)
/
CREATE INDEX KSDO_DOCUMENT_I2 
  ON KSDO_DOCUMENT 
  (TYPE)
/





-----------------------------------------------------------------------------
-- KSDO_DOCUMENT_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSDO_DOCUMENT_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSDO_DOCUMENT_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSDO_DOCUMENT_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSDO_DOCUMENT_ATTR
    ADD CONSTRAINT KSDO_DOCUMENT_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSDO_DOCUMENT_ATTR_I1 
  ON KSDO_DOCUMENT_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSDO_DOCUMENT_CATEGORY
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSDO_DOCUMENT_CATEGORY';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSDO_DOCUMENT_CATEGORY CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSDO_DOCUMENT_CATEGORY
(
      CATEGORY_ID VARCHAR2(255)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , RT_DESCR_ID VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSDO_DOCUMENT_CATEGORY
    ADD CONSTRAINT KSDO_DOCUMENT_CATEGORYP1
PRIMARY KEY (CATEGORY_ID)
/


CREATE INDEX KSDO_DOCUMENT_CATEGORY_I1 
  ON KSDO_DOCUMENT_CATEGORY 
  (RT_DESCR_ID)
/





-----------------------------------------------------------------------------
-- KSDO_DOCUMENT_CATEGORY_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSDO_DOCUMENT_CATEGORY_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSDO_DOCUMENT_CATEGORY_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSDO_DOCUMENT_CATEGORY_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSDO_DOCUMENT_CATEGORY_ATTR
    ADD CONSTRAINT KSDO_DOCUMENT_CATEGORY_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSDO_DOC_CATEGORY_ATTR_I1 
  ON KSDO_DOCUMENT_CATEGORY_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSDO_DOCUMENT_JN_DOC_CATEGORY
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSDO_DOCUMENT_JN_DOC_CATEGORY';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSDO_DOCUMENT_JN_DOC_CATEGORY CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSDO_DOCUMENT_JN_DOC_CATEGORY
(
      DOC_ID VARCHAR2(255) NOT NULL
        , CATEGORY_ID VARCHAR2(255) NOT NULL
    

)
/



CREATE INDEX KSDO_DOC_JN_DOC_CATEGORY_I1 
  ON KSDO_DOCUMENT_JN_DOC_CATEGORY 
  (DOC_ID)
/
CREATE INDEX KSDO_DOC_JN_DOC_CATEGORY_I2 
  ON KSDO_DOCUMENT_JN_DOC_CATEGORY 
  (CATEGORY_ID)
/





-----------------------------------------------------------------------------
-- KSDO_DOCUMENT_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSDO_DOCUMENT_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSDO_DOCUMENT_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSDO_DOCUMENT_TYPE
(
      TYPE_KEY VARCHAR2(255)
        , TYPE_DESC VARCHAR2(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSDO_DOCUMENT_TYPE
    ADD CONSTRAINT KSDO_DOCUMENT_TYPEP1
PRIMARY KEY (TYPE_KEY)
/







-----------------------------------------------------------------------------
-- KSDO_DOCUMENT_TYPE_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSDO_DOCUMENT_TYPE_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSDO_DOCUMENT_TYPE_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSDO_DOCUMENT_TYPE_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSDO_DOCUMENT_TYPE_ATTR
    ADD CONSTRAINT KSDO_DOCUMENT_TYPE_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSDO_DOCUMENT_TYPE_ATTR_I1 
  ON KSDO_DOCUMENT_TYPE_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSDO_REF_DOC_RELTN
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSDO_REF_DOC_RELTN';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSDO_REF_DOC_RELTN CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSDO_REF_DOC_RELTN
(
      ID VARCHAR2(255)
        , CREATEID VARCHAR2(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR2(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR NUMBER(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , REF_OBJ_ID VARCHAR2(255)
        , ST VARCHAR2(255)
        , TITLE VARCHAR2(255)
        , RT_DESCR_ID VARCHAR2(255)
        , DOC_ID VARCHAR2(255)
        , TYPE_KEY VARCHAR2(255)
        , REF_OBJ_TYPE_KEY VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
    

)
/

ALTER TABLE KSDO_REF_DOC_RELTN
    ADD CONSTRAINT KSDO_REF_DOC_RELTNP1
PRIMARY KEY (ID)
/


CREATE INDEX KSDO_REF_DOC_RELTN_I1 
  ON KSDO_REF_DOC_RELTN 
  (TYPE_KEY)
/
CREATE INDEX KSDO_REF_DOC_RELTN_I2 
  ON KSDO_REF_DOC_RELTN 
  (REF_OBJ_TYPE_KEY)
/
CREATE INDEX KSDO_REF_DOC_RELTN_I3 
  ON KSDO_REF_DOC_RELTN 
  (RT_DESCR_ID)
/
CREATE INDEX KSDO_REF_DOC_RELTN_I4 
  ON KSDO_REF_DOC_RELTN 
  (DOC_ID)
/





-----------------------------------------------------------------------------
-- KSDO_REF_DOC_RELTN_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSDO_REF_DOC_RELTN_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSDO_REF_DOC_RELTN_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSDO_REF_DOC_RELTN_TYPE
(
      TYPE_KEY VARCHAR2(255)
        , TYPE_DESC VARCHAR2(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSDO_REF_DOC_RELTN_TYPE
    ADD CONSTRAINT KSDO_REF_DOC_RELTN_TYPEP1
PRIMARY KEY (TYPE_KEY)
/







-----------------------------------------------------------------------------
-- KSDO_REF_DOC_RELTN_TYPE_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSDO_REF_DOC_RELTN_TYPE_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSDO_REF_DOC_RELTN_TYPE_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSDO_REF_DOC_RELTN_TYPE_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSDO_REF_DOC_RELTN_TYPE_ATTR
    ADD CONSTRAINT KSDO_REF_DOC_RELTN_TYPE_ATTP1
PRIMARY KEY (ID)
/


CREATE INDEX KSDO_REF_DOC_REL_TYP_ATTR_I1 
  ON KSDO_REF_DOC_RELTN_TYPE_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSDO_REF_DOC_REL_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSDO_REF_DOC_REL_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSDO_REF_DOC_REL_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSDO_REF_DOC_REL_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSDO_REF_DOC_REL_ATTR
    ADD CONSTRAINT KSDO_REF_DOC_REL_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSDO_REF_DOC_REL_ATTR_I1 
  ON KSDO_REF_DOC_REL_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSDO_REF_OBJ_SUB_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSDO_REF_OBJ_SUB_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSDO_REF_OBJ_SUB_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSDO_REF_OBJ_SUB_TYPE
(
      TYPE_KEY VARCHAR2(255)
        , TYPE_DESC VARCHAR2(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , REF_OBJ_TYPE_KEY VARCHAR2(255)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSDO_REF_OBJ_SUB_TYPE
    ADD CONSTRAINT KSDO_REF_OBJ_SUB_TYPEP1
PRIMARY KEY (TYPE_KEY)
/


CREATE INDEX KSDO_REF_OBJ_SUB_TYPE_I1 
  ON KSDO_REF_OBJ_SUB_TYPE 
  (REF_OBJ_TYPE_KEY)
/





-----------------------------------------------------------------------------
-- KSDO_REF_OBJ_SUB_TYPE_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSDO_REF_OBJ_SUB_TYPE_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSDO_REF_OBJ_SUB_TYPE_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSDO_REF_OBJ_SUB_TYPE_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSDO_REF_OBJ_SUB_TYPE_ATTR
    ADD CONSTRAINT KSDO_REF_OBJ_SUB_TYPE_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSDO_REF_OBJ_SUB_TYPE_ATTR_I1 
  ON KSDO_REF_OBJ_SUB_TYPE_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSDO_REF_OBJ_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSDO_REF_OBJ_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSDO_REF_OBJ_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSDO_REF_OBJ_TYPE
(
      TYPE_KEY VARCHAR2(255)
        , TYPE_DESC VARCHAR2(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSDO_REF_OBJ_TYPE
    ADD CONSTRAINT KSDO_REF_OBJ_TYPEP1
PRIMARY KEY (TYPE_KEY)
/







-----------------------------------------------------------------------------
-- KSDO_REF_OBJ_TYPE_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSDO_REF_OBJ_TYPE_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSDO_REF_OBJ_TYPE_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSDO_REF_OBJ_TYPE_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSDO_REF_OBJ_TYPE_ATTR
    ADD CONSTRAINT KSDO_REF_OBJ_TYPE_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSDO_REF_OBJ_TYPE_ATTR_I1 
  ON KSDO_REF_OBJ_TYPE_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSDO_REF_REL_TYP_JN_SUB_TYP
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSDO_REF_REL_TYP_JN_SUB_TYP';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSDO_REF_REL_TYP_JN_SUB_TYP CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSDO_REF_REL_TYP_JN_SUB_TYP
(
      REF_DOC_RELTN_TYPE_KEY VARCHAR2(255) NOT NULL
        , REF_OBJ_SUB_TYPE_KEY VARCHAR2(255) NOT NULL
    

)
/



CREATE INDEX KSDO_REF_REL_TYP_JN_SUBTYP_I1 
  ON KSDO_REF_REL_TYP_JN_SUB_TYP 
  (REF_OBJ_SUB_TYPE_KEY)
/
CREATE INDEX KSDO_REF_REL_TYP_JN_SUBTYP_I2 
  ON KSDO_REF_REL_TYP_JN_SUB_TYP 
  (REF_DOC_RELTN_TYPE_KEY)
/





-----------------------------------------------------------------------------
-- KSDO_RICH_TEXT_T
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSDO_RICH_TEXT_T';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSDO_RICH_TEXT_T CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSDO_RICH_TEXT_T
(
      ID VARCHAR2(255)
        , FORMATTED VARCHAR2(2000)
        , PLAIN VARCHAR2(2000)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSDO_RICH_TEXT_T
    ADD CONSTRAINT KSDO_RICH_TEXT_TP1
PRIMARY KEY (ID)
/







-----------------------------------------------------------------------------
-- KSEM_CTX_JN_ENUM_VAL_T
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSEM_CTX_JN_ENUM_VAL_T';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSEM_CTX_JN_ENUM_VAL_T CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSEM_CTX_JN_ENUM_VAL_T
(
      ENUM_VAL_ID VARCHAR2(255) NOT NULL
        , CTX_ID VARCHAR2(255) NOT NULL
    

)
/



CREATE INDEX KSEM_CTX_JN_ENUM_VAL_T_I1 
  ON KSEM_CTX_JN_ENUM_VAL_T 
  (CTX_ID)
/
CREATE INDEX KSEM_CTX_JN_ENUM_VAL_T_I2 
  ON KSEM_CTX_JN_ENUM_VAL_T 
  (ENUM_VAL_ID)
/





-----------------------------------------------------------------------------
-- KSEM_CTX_T
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSEM_CTX_T';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSEM_CTX_T CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSEM_CTX_T
(
      ID VARCHAR2(255)
        , CTX_KEY VARCHAR2(255)
        , CTX_VAL VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    
    , CONSTRAINT SYS_C00285110 UNIQUE (CTX_KEY, CTX_VAL)

)
/

ALTER TABLE KSEM_CTX_T
    ADD CONSTRAINT KSEM_CTX_TP1
PRIMARY KEY (ID)
/







-----------------------------------------------------------------------------
-- KSEM_ENUM_T
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSEM_ENUM_T';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSEM_ENUM_T CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSEM_ENUM_T
(
      ENUM_KEY VARCHAR2(255)
        , DESCR VARCHAR2(255)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSEM_ENUM_T
    ADD CONSTRAINT KSEM_ENUM_TP1
PRIMARY KEY (ENUM_KEY)
/







-----------------------------------------------------------------------------
-- KSEM_ENUM_VAL_T
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSEM_ENUM_VAL_T';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSEM_ENUM_VAL_T CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSEM_ENUM_VAL_T
(
      ID VARCHAR2(255)
        , ABBREV_VAL VARCHAR2(255)
        , CD VARCHAR2(255)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , SORT_KEY NUMBER(10)
        , VAL VARCHAR2(255)
        , ENUM_KEY VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSEM_ENUM_VAL_T
    ADD CONSTRAINT KSEM_ENUM_VAL_TP1
PRIMARY KEY (ID)
/


CREATE INDEX KSEM_ENUM_VAL_I2 
  ON KSEM_ENUM_VAL_T 
  (CD)
/
CREATE INDEX KSEM_ENUM_VAL_T_I1 
  ON KSEM_ENUM_VAL_T 
  (ENUM_KEY)
/





-----------------------------------------------------------------------------
-- KSLO_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLO_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLO_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLO_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLO_ATTR
    ADD CONSTRAINT KSLO_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLO_ATTR_I1 
  ON KSLO_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSLO_LO
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLO_LO';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLO_LO CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLO_LO
(
      ID VARCHAR2(255)
        , CREATEID VARCHAR2(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR2(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR NUMBER(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , ST VARCHAR2(255)
        , RT_DESCR_ID VARCHAR2(255)
        , LO_REPO_ID VARCHAR2(255)
        , LOTYPE_ID VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
    

)
/

ALTER TABLE KSLO_LO
    ADD CONSTRAINT KSLO_LOP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLO_LO_I1 
  ON KSLO_LO 
  (RT_DESCR_ID)
/
CREATE INDEX KSLO_LO_I2 
  ON KSLO_LO 
  (LOTYPE_ID)
/
CREATE INDEX KSLO_LO_I3 
  ON KSLO_LO 
  (LO_REPO_ID)
/





-----------------------------------------------------------------------------
-- KSLO_LO_ALLOWED_RELTN_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLO_LO_ALLOWED_RELTN_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLO_LO_ALLOWED_RELTN_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLO_LO_ALLOWED_RELTN_TYPE
(
      ID VARCHAR2(255)
        , CREATEID VARCHAR2(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR2(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR NUMBER(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , LO_TYPE_ID VARCHAR2(255)
        , LO_REL_TYPE_ID VARCHAR2(255)
        , LOLO_RELTN_TYPE_ID VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
    

)
/

ALTER TABLE KSLO_LO_ALLOWED_RELTN_TYPE
    ADD CONSTRAINT KSLO_LO_ALLOWED_RELTN_TYPEP1
PRIMARY KEY (ID)
/







-----------------------------------------------------------------------------
-- KSLO_LO_CATEGORY
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLO_LO_CATEGORY';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLO_LO_CATEGORY CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLO_LO_CATEGORY
(
      ID VARCHAR2(255)
        , CREATEID VARCHAR2(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR2(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR NUMBER(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , STATE VARCHAR2(255)
        , RT_DESCR_ID VARCHAR2(255)
        , LO_CATEGORY_TYPE_ID VARCHAR2(255)
        , LO_REPO_ID VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
    

)
/

ALTER TABLE KSLO_LO_CATEGORY
    ADD CONSTRAINT KSLO_LO_CATEGORYP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLO_LO_CATEGORY_I1 
  ON KSLO_LO_CATEGORY 
  (RT_DESCR_ID)
/
CREATE INDEX KSLO_LO_CATEGORY_I2 
  ON KSLO_LO_CATEGORY 
  (LO_REPO_ID)
/
CREATE INDEX KSLO_LO_CATEGORY_I3 
  ON KSLO_LO_CATEGORY 
  (LO_CATEGORY_TYPE_ID)
/





-----------------------------------------------------------------------------
-- KSLO_LO_CATEGORY_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLO_LO_CATEGORY_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLO_LO_CATEGORY_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLO_LO_CATEGORY_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLO_LO_CATEGORY_ATTR
    ADD CONSTRAINT KSLO_LO_CATEGORY_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLO_LO_CATEGORY_ATTR_I1 
  ON KSLO_LO_CATEGORY_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSLO_LO_CATEGORY_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLO_LO_CATEGORY_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLO_LO_CATEGORY_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLO_LO_CATEGORY_TYPE
(
      ID VARCHAR2(255)
        , DESCR VARCHAR2(255)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , TYPE_KEY VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
        , TYPE_DESC VARCHAR2(2000)
    

)
/

ALTER TABLE KSLO_LO_CATEGORY_TYPE
    ADD CONSTRAINT KSLO_LO_CATEGORY_TYPEP1
PRIMARY KEY (ID)
/







-----------------------------------------------------------------------------
-- KSLO_LO_CATEGORY_TYPE_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLO_LO_CATEGORY_TYPE_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLO_LO_CATEGORY_TYPE_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLO_LO_CATEGORY_TYPE_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLO_LO_CATEGORY_TYPE_ATTR
    ADD CONSTRAINT KSLO_LO_CATEGORY_TYPE_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLO_LO_CATEGORY_TYPE_ATTR_I1 
  ON KSLO_LO_CATEGORY_TYPE_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSLO_LO_JN_LOCATEGORY
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLO_LO_JN_LOCATEGORY';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLO_LO_JN_LOCATEGORY CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLO_LO_JN_LOCATEGORY
(
      ID VARCHAR2(255)
        , LO_ID VARCHAR2(255)
        , LOCATEGORY_ID VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    
    , CONSTRAINT SYS_C0011301 UNIQUE (LO_ID, LOCATEGORY_ID)

)
/

ALTER TABLE KSLO_LO_JN_LOCATEGORY
    ADD CONSTRAINT KSLO_LO_JN_LOCATEGORYP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLO_LO_JN_LOCATEGORY_I1 
  ON KSLO_LO_JN_LOCATEGORY 
  (LOCATEGORY_ID)
/
CREATE INDEX KSLO_LO_JN_LOCATEGORY_I2 
  ON KSLO_LO_JN_LOCATEGORY 
  (LO_ID)
/





-----------------------------------------------------------------------------
-- KSLO_LO_RELTN
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLO_LO_RELTN';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLO_LO_RELTN CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLO_LO_RELTN
(
      ID VARCHAR2(255)
        , CREATEID VARCHAR2(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR2(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR NUMBER(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , ST VARCHAR2(255)
        , LO_ID VARCHAR2(255)
        , LO_LO_RELATION_TYPE_ID VARCHAR2(255)
        , RELATED_LO_ID VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
    

)
/

ALTER TABLE KSLO_LO_RELTN
    ADD CONSTRAINT KSLO_LO_RELTNP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLO_LO_RELTN_I1 
  ON KSLO_LO_RELTN 
  (LO_LO_RELATION_TYPE_ID)
/
CREATE INDEX KSLO_LO_RELTN_I2 
  ON KSLO_LO_RELTN 
  (RELATED_LO_ID)
/
CREATE INDEX KSLO_LO_RELTN_I3 
  ON KSLO_LO_RELTN 
  (LO_ID)
/





-----------------------------------------------------------------------------
-- KSLO_LO_RELTN_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLO_LO_RELTN_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLO_LO_RELTN_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLO_LO_RELTN_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLO_LO_RELTN_ATTR
    ADD CONSTRAINT KSLO_LO_RELTN_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLO_LO_RELTN_ATTR_I1 
  ON KSLO_LO_RELTN_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSLO_LO_RELTN_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLO_LO_RELTN_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLO_LO_RELTN_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLO_LO_RELTN_TYPE
(
      ID VARCHAR2(255)
        , DESCR VARCHAR2(255)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , REV_DESCR VARCHAR2(255)
        , REV_NAME VARCHAR2(255)
        , TYPE_KEY VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
        , TYPE_DESC VARCHAR2(2000)
    

)
/

ALTER TABLE KSLO_LO_RELTN_TYPE
    ADD CONSTRAINT KSLO_LO_RELTN_TYPEP1
PRIMARY KEY (ID)
/







-----------------------------------------------------------------------------
-- KSLO_LO_RELTN_TYPE_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLO_LO_RELTN_TYPE_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLO_LO_RELTN_TYPE_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLO_LO_RELTN_TYPE_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLO_LO_RELTN_TYPE_ATTR
    ADD CONSTRAINT KSLO_LO_RELTN_TYPE_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLO_LO_RELTN_TYPE_ATTR_I1 
  ON KSLO_LO_RELTN_TYPE_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSLO_LO_REPOSITORY
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLO_LO_REPOSITORY';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLO_LO_REPOSITORY CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLO_LO_REPOSITORY
(
      ID VARCHAR2(255)
        , CREATEID VARCHAR2(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR2(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR NUMBER(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , RT_DESCR_ID VARCHAR2(255)
        , LO_ROOT_ID VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
    

)
/

ALTER TABLE KSLO_LO_REPOSITORY
    ADD CONSTRAINT KSLO_LO_REPOSITORYP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLO_LO_REPOSITORY_I1 
  ON KSLO_LO_REPOSITORY 
  (LO_ROOT_ID)
/
CREATE INDEX KSLO_LO_REPOSITORY_I2 
  ON KSLO_LO_REPOSITORY 
  (RT_DESCR_ID)
/





-----------------------------------------------------------------------------
-- KSLO_LO_REPOSITORY_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLO_LO_REPOSITORY_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLO_LO_REPOSITORY_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLO_LO_REPOSITORY_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLO_LO_REPOSITORY_ATTR
    ADD CONSTRAINT KSLO_LO_REPOSITORY_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLO_LO_REPOSITORY_ATTR_I1 
  ON KSLO_LO_REPOSITORY_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSLO_LO_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLO_LO_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLO_LO_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLO_LO_TYPE
(
      ID VARCHAR2(255)
        , DESCR VARCHAR2(255)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , TYPE_KEY VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
        , TYPE_DESC VARCHAR2(2000)
    

)
/

ALTER TABLE KSLO_LO_TYPE
    ADD CONSTRAINT KSLO_LO_TYPEP1
PRIMARY KEY (ID)
/







-----------------------------------------------------------------------------
-- KSLO_LO_TYPE_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLO_LO_TYPE_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLO_LO_TYPE_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLO_LO_TYPE_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLO_LO_TYPE_ATTR
    ADD CONSTRAINT KSLO_LO_TYPE_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLO_LO_TYPE_ATTR_I1 
  ON KSLO_LO_TYPE_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSLO_RICH_TEXT_T
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLO_RICH_TEXT_T';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLO_RICH_TEXT_T CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLO_RICH_TEXT_T
(
      ID VARCHAR2(255)
        , FORMATTED VARCHAR2(2000)
        , PLAIN VARCHAR2(2000)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLO_RICH_TEXT_T
    ADD CONSTRAINT KSLO_RICH_TEXT_TP1
PRIMARY KEY (ID)
/







-----------------------------------------------------------------------------
-- KSLR_RESCOMP
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLR_RESCOMP';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLR_RESCOMP CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLR_RESCOMP
(
      ID VARCHAR2(255)
        , CREATEID VARCHAR2(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR2(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR NUMBER(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , STATE VARCHAR2(255)
        , RT_DESCR_ID VARCHAR2(255)
        , TYPE VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
    

)
/

ALTER TABLE KSLR_RESCOMP
    ADD CONSTRAINT KSLR_RESCOMPP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLR_RESCOMP_I1 
  ON KSLR_RESCOMP 
  (TYPE)
/
CREATE INDEX KSLR_RESCOMP_I2 
  ON KSLR_RESCOMP 
  (RT_DESCR_ID)
/





-----------------------------------------------------------------------------
-- KSLR_RESCOMP_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLR_RESCOMP_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLR_RESCOMP_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLR_RESCOMP_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLR_RESCOMP_ATTR
    ADD CONSTRAINT KSLR_RESCOMP_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLR_RESCOMP_ATTR_I1 
  ON KSLR_RESCOMP_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSLR_RESCOMP_JN_RESVALUE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLR_RESCOMP_JN_RESVALUE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLR_RESCOMP_JN_RESVALUE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLR_RESCOMP_JN_RESVALUE
(
      COMPONENT_ID VARCHAR2(255) NOT NULL
        , RESULT_ID VARCHAR2(255) NOT NULL
    

)
/








-----------------------------------------------------------------------------
-- KSLR_RESCOMP_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLR_RESCOMP_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLR_RESCOMP_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLR_RESCOMP_TYPE
(
      TYPE_KEY VARCHAR2(255)
        , TYPE_DESC VARCHAR2(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLR_RESCOMP_TYPE
    ADD CONSTRAINT KSLR_RESCOMP_TYPEP1
PRIMARY KEY (TYPE_KEY)
/







-----------------------------------------------------------------------------
-- KSLR_RESCOMP_TYPE_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLR_RESCOMP_TYPE_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLR_RESCOMP_TYPE_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLR_RESCOMP_TYPE_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLR_RESCOMP_TYPE_ATTR
    ADD CONSTRAINT KSLR_RESCOMP_TYPE_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLR_RESCOMP_TYPE_ATTR_I1 
  ON KSLR_RESCOMP_TYPE_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSLR_RESULT_VALUE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLR_RESULT_VALUE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLR_RESULT_VALUE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLR_RESULT_VALUE
(
      ID VARCHAR2(255)
        , VALUE VARCHAR2(255)
        , RSLT_COMP_ID VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLR_RESULT_VALUE
    ADD CONSTRAINT KSLR_RESULT_VALUEP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLR_RESULT_VALUE_I1 
  ON KSLR_RESULT_VALUE 
  (RSLT_COMP_ID)
/





-----------------------------------------------------------------------------
-- KSLR_RICH_TEXT_T
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLR_RICH_TEXT_T';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLR_RICH_TEXT_T CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLR_RICH_TEXT_T
(
      ID VARCHAR2(255)
        , FORMATTED VARCHAR2(2000)
        , PLAIN VARCHAR2(2000)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLR_RICH_TEXT_T
    ADD CONSTRAINT KSLR_RICH_TEXT_TP1
PRIMARY KEY (ID)
/







-----------------------------------------------------------------------------
-- KSLR_SCALE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLR_SCALE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLR_SCALE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLR_SCALE
(
      ID VARCHAR2(255)
        , CREATEID VARCHAR2(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR2(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR NUMBER(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , RT_DESCR_ID VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
    

)
/

ALTER TABLE KSLR_SCALE
    ADD CONSTRAINT KSLR_SCALEP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLR_SCALE_I1 
  ON KSLR_SCALE 
  (RT_DESCR_ID)
/





-----------------------------------------------------------------------------
-- KSLR_SCALE_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLR_SCALE_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLR_SCALE_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLR_SCALE_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLR_SCALE_ATTR
    ADD CONSTRAINT KSLR_SCALE_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLR_SCALE_ATTR_I1 
  ON KSLR_SCALE_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSLU_CLU
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU
(
      ID VARCHAR2(255)
        , CREATEID VARCHAR2(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR2(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR NUMBER(19) NOT NULL
        , CURR_VER_END TIMESTAMP
        , CURR_VER_START TIMESTAMP
        , SEQ_NUM NUMBER(19)
        , VER_CMT VARCHAR2(255)
        , VER_IND_ID VARCHAR2(255)
        , VER_FROM_ID VARCHAR2(255)
        , CAN_CREATE_LUI NUMBER(1)
        , DEF_ENRL_EST NUMBER(10)
        , DEF_MAX_ENRL NUMBER(10)
        , EFF_DT TIMESTAMP
        , EXP_FIRST_ATP VARCHAR2(255)
        , EXPIR_DT TIMESTAMP
        , HAS_EARLY_DROP_DEDLN NUMBER(1)
        , CLU_INTSTY_QTY VARCHAR2(255)
        , CLU_INTSTY_TYPE VARCHAR2(255)
        , IS_ENRL NUMBER(1)
        , IS_HAZR_DISBLD_STU NUMBER(1)
        , LAST_ADMIT_ATP VARCHAR2(255)
        , LAST_ATP VARCHAR2(255)
        , NEXT_REVIEW_PRD VARCHAR2(255)
        , REF_URL VARCHAR2(255)
        , ST VARCHAR2(255)
        , ATP_DUR_TYP_KEY VARCHAR2(255)
        , TM_QUANTITY NUMBER(10)
        , STDY_SUBJ_AREA VARCHAR2(255)
        , ACCT_ID VARCHAR2(255)
        , RT_DESCR_ID VARCHAR2(255)
        , FEE_ID VARCHAR2(255)
        , LUTYPE_ID VARCHAR2(255)
        , OFFIC_CLU_ID VARCHAR2(255)
        , PRI_INSTR_ID VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
    
    , CONSTRAINT SYS_C0011370 UNIQUE (VER_IND_ID, SEQ_NUM)

)
/

ALTER TABLE KSLU_CLU
    ADD CONSTRAINT KSLU_CLUP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_CLU_I1 
  ON KSLU_CLU 
  (PRI_INSTR_ID)
/
CREATE INDEX KSLU_CLU_I2 
  ON KSLU_CLU 
  (LUTYPE_ID)
/
CREATE INDEX KSLU_CLU_I3 
  ON KSLU_CLU 
  (RT_DESCR_ID)
/
CREATE INDEX KSLU_CLU_I4 
  ON KSLU_CLU 
  (FEE_ID)
/
CREATE INDEX KSLU_CLU_I5 
  ON KSLU_CLU 
  (OFFIC_CLU_ID)
/
CREATE INDEX KSLU_CLU_I6 
  ON KSLU_CLU 
  (ACCT_ID)
/





-----------------------------------------------------------------------------
-- KSLU_CLUCLU_RELTN
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLUCLU_RELTN';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLUCLU_RELTN CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLUCLU_RELTN
(
      ID VARCHAR2(255)
        , CREATEID VARCHAR2(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR2(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR NUMBER(19) NOT NULL
        , CLU_RELTN_REQ NUMBER(1)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , ST VARCHAR2(255)
        , CLU_ID VARCHAR2(255)
        , LU_RELTN_TYPE_ID VARCHAR2(255)
        , RELATED_CLU_ID VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
    

)
/

ALTER TABLE KSLU_CLUCLU_RELTN
    ADD CONSTRAINT KSLU_CLUCLU_RELTNP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_CLUCLU_RELTN_I1 
  ON KSLU_CLUCLU_RELTN 
  (CLU_ID)
/
CREATE INDEX KSLU_CLUCLU_RELTN_I2 
  ON KSLU_CLUCLU_RELTN 
  (RELATED_CLU_ID)
/
CREATE INDEX KSLU_CLUCLU_RELTN_I3 
  ON KSLU_CLUCLU_RELTN 
  (LU_RELTN_TYPE_ID)
/





-----------------------------------------------------------------------------
-- KSLU_CLUCLU_RELTN_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLUCLU_RELTN_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLUCLU_RELTN_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLUCLU_RELTN_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_CLUCLU_RELTN_ATTR
    ADD CONSTRAINT KSLU_CLUCLU_RELTN_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_CLUCLU_RELTN_ATTR_I1 
  ON KSLU_CLUCLU_RELTN_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSLU_CLURES_JN_RESOPT
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLURES_JN_RESOPT';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLURES_JN_RESOPT CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLURES_JN_RESOPT
(
      CLU_RES_ID VARCHAR2(255) NOT NULL
        , RES_OPT_ID VARCHAR2(255) NOT NULL
    
    , CONSTRAINT SYS_C0011378 UNIQUE (RES_OPT_ID)

)
/



CREATE INDEX KSLU_CLURES_JN_RESOPT_I1 
  ON KSLU_CLURES_JN_RESOPT 
  (CLU_RES_ID)
/





-----------------------------------------------------------------------------
-- KSLU_CLU_ACCRED
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_ACCRED';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_ACCRED CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_ACCRED
(
      ID VARCHAR2(255)
        , CREATEID VARCHAR2(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR2(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR NUMBER(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , ORG_ID VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
    

)
/

ALTER TABLE KSLU_CLU_ACCRED
    ADD CONSTRAINT KSLU_CLU_ACCREDP1
PRIMARY KEY (ID)
/







-----------------------------------------------------------------------------
-- KSLU_CLU_ACCRED_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_ACCRED_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_ACCRED_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_ACCRED_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_CLU_ACCRED_ATTR
    ADD CONSTRAINT KSLU_CLU_ACCRED_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_CLU_ACCRED_ATTR_I1 
  ON KSLU_CLU_ACCRED_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSLU_CLU_ACCT
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_ACCT';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_ACCT CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_ACCT
(
      ID VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_CLU_ACCT
    ADD CONSTRAINT KSLU_CLU_ACCTP1
PRIMARY KEY (ID)
/







-----------------------------------------------------------------------------
-- KSLU_CLU_ACCT_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_ACCT_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_ACCT_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_ACCT_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_CLU_ACCT_ATTR
    ADD CONSTRAINT KSLU_CLU_ACCT_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_CLU_ACCT_ATTR_I1 
  ON KSLU_CLU_ACCT_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSLU_CLU_ACCT_JN_AFFIL_ORG
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_ACCT_JN_AFFIL_ORG';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_ACCT_JN_AFFIL_ORG CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_ACCT_JN_AFFIL_ORG
(
      CLU_ACCT_ID VARCHAR2(255) NOT NULL
        , AFFIL_ORG_ID VARCHAR2(255) NOT NULL
    

)
/



CREATE INDEX KSLU_CLU_ACCT_JN_AFFIL_ORG_I1 
  ON KSLU_CLU_ACCT_JN_AFFIL_ORG 
  (AFFIL_ORG_ID)
/
CREATE INDEX KSLU_CLU_ACCT_JN_AFFIL_ORG_I2 
  ON KSLU_CLU_ACCT_JN_AFFIL_ORG 
  (CLU_ACCT_ID)
/





-----------------------------------------------------------------------------
-- KSLU_CLU_ADMIN_ORG
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_ADMIN_ORG';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_ADMIN_ORG CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_ADMIN_ORG
(
      ID VARCHAR2(255)
        , IS_PR NUMBER(1)
        , ORG_ID VARCHAR2(255)
        , TYPE VARCHAR2(255)
        , CLU_ID VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_CLU_ADMIN_ORG
    ADD CONSTRAINT KSLU_CLU_ADMIN_ORGP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_CLU_ADMIN_ORG_I1 
  ON KSLU_CLU_ADMIN_ORG 
  (CLU_ID)
/





-----------------------------------------------------------------------------
-- KSLU_CLU_ADMIN_ORG_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_ADMIN_ORG_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_ADMIN_ORG_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_ADMIN_ORG_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_CLU_ADMIN_ORG_ATTR
    ADD CONSTRAINT KSLU_CLU_ADMIN_ORG_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_CLU_ADMIN_ORG_ATTR_I1 
  ON KSLU_CLU_ADMIN_ORG_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSLU_CLU_AFFIL_ORG
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_AFFIL_ORG';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_AFFIL_ORG CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_AFFIL_ORG
(
      ID VARCHAR2(255)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , ORG_ID VARCHAR2(255)
        , PERCT NUMBER(19)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_CLU_AFFIL_ORG
    ADD CONSTRAINT KSLU_CLU_AFFIL_ORGP1
PRIMARY KEY (ID)
/







-----------------------------------------------------------------------------
-- KSLU_CLU_ATP_TYPE_KEY
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_ATP_TYPE_KEY';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_ATP_TYPE_KEY CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_ATP_TYPE_KEY
(
      ID VARCHAR2(255)
        , ATP_TYPE_KEY VARCHAR2(255)
        , CLU_ID VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_CLU_ATP_TYPE_KEY
    ADD CONSTRAINT KSLU_CLU_ATP_TYPE_KEYP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_CLU_ATP_TYPE_KEY_I1 
  ON KSLU_CLU_ATP_TYPE_KEY 
  (CLU_ID)
/





-----------------------------------------------------------------------------
-- KSLU_CLU_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_CLU_ATTR
    ADD CONSTRAINT KSLU_CLU_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_CLU_ATTR_I1 
  ON KSLU_CLU_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSLU_CLU_CR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_CR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_CR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_CR
(
      ID VARCHAR2(255)
        , INSTR_UNIT NUMBER(10)
        , MAX_ALOW_INACV_ATP VARCHAR2(255)
        , MAX_ALOW_INACV_TMQ NUMBER(10)
        , MAX_TM_RSLT_RCGZ_ATP VARCHAR2(255)
        , MAX_TM_RSLT_RCGZ_TMQ NUMBER(10)
        , MAX_TM_TO_COMP_ATP VARCHAR2(255)
        , MAX_TM_TO_COMP_TMQ NUMBER(10)
        , MAX_TOT_UNIT NUMBER(10)
        , MIN_TM_TO_COMP_ATP VARCHAR2(255)
        , MIN_TM_TO_COMP_TMQ NUMBER(10)
        , MIN_TOT_UNIT NUMBER(10)
        , REPEAT_CNT VARCHAR2(255)
        , REPEAT_TM_ATP VARCHAR2(255)
        , REPEAT_TM_TMQ NUMBER(10)
        , REPEAT_UNIT VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_CLU_CR
    ADD CONSTRAINT KSLU_CLU_CRP1
PRIMARY KEY (ID)
/







-----------------------------------------------------------------------------
-- KSLU_CLU_FEE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_FEE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_FEE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_FEE
(
      ID VARCHAR2(255)
        , CREATEID VARCHAR2(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR2(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR NUMBER(19) NOT NULL
        , RT_DESCR_ID VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
    

)
/

ALTER TABLE KSLU_CLU_FEE
    ADD CONSTRAINT KSLU_CLU_FEEP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_CLU_FEE_I1 
  ON KSLU_CLU_FEE 
  (RT_DESCR_ID)
/





-----------------------------------------------------------------------------
-- KSLU_CLU_FEEREC_JN_AFFIL_ORG
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_FEEREC_JN_AFFIL_ORG';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_FEEREC_JN_AFFIL_ORG CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_FEEREC_JN_AFFIL_ORG
(
      CLU_FEE_REC_ID VARCHAR2(255) NOT NULL
        , AFFIL_ORG_ID VARCHAR2(255) NOT NULL
    

)
/



CREATE INDEX KSLU_CLU_FEEREC_JN_AFF_ORG_I1 
  ON KSLU_CLU_FEEREC_JN_AFFIL_ORG 
  (AFFIL_ORG_ID)
/
CREATE INDEX KSLU_CLU_FEEREC_JN_AFF_ORG_I2 
  ON KSLU_CLU_FEEREC_JN_AFFIL_ORG 
  (CLU_FEE_REC_ID)
/





-----------------------------------------------------------------------------
-- KSLU_CLU_FEE_AMOUNT
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_FEE_AMOUNT';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_FEE_AMOUNT CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_FEE_AMOUNT
(
      ID VARCHAR2(255)
        , CURRENCY_QUANT NUMBER(10)
        , CURRENCY_TYPE VARCHAR2(255)
        , CLUE_FEE_REC_ID VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_CLU_FEE_AMOUNT
    ADD CONSTRAINT KSLU_CLU_FEE_AMOUNTP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_CLU_FEE_AMOUNT_I1 
  ON KSLU_CLU_FEE_AMOUNT 
  (CLUE_FEE_REC_ID)
/





-----------------------------------------------------------------------------
-- KSLU_CLU_FEE_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_FEE_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_FEE_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_FEE_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_CLU_FEE_ATTR
    ADD CONSTRAINT KSLU_CLU_FEE_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_CLU_FEE_ATTR_I1 
  ON KSLU_CLU_FEE_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSLU_CLU_FEE_JN_CLU_FEE_REC
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_FEE_JN_CLU_FEE_REC';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_FEE_JN_CLU_FEE_REC CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_FEE_JN_CLU_FEE_REC
(
      CLU_FEE_ID VARCHAR2(255) NOT NULL
        , CLU_FEE_REC_ID VARCHAR2(255) NOT NULL
    

)
/



CREATE INDEX KSLU_CLUFEE_JN_CLUFEE_REC_I1 
  ON KSLU_CLU_FEE_JN_CLU_FEE_REC 
  (CLU_FEE_REC_ID)
/
CREATE INDEX KSLU_CLUFEE_JN_CLUFEE_REC_I2 
  ON KSLU_CLU_FEE_JN_CLU_FEE_REC 
  (CLU_FEE_ID)
/





-----------------------------------------------------------------------------
-- KSLU_CLU_FEE_REC
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_FEE_REC';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_FEE_REC CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_FEE_REC
(
      ID VARCHAR2(255)
        , CREATEID VARCHAR2(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR2(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR NUMBER(19) NOT NULL
        , FEE_TYPE VARCHAR2(255)
        , RATE_TYPE VARCHAR2(255)
        , RT_DESCR_ID VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
    

)
/

ALTER TABLE KSLU_CLU_FEE_REC
    ADD CONSTRAINT KSLU_CLU_FEE_RECP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_CLU_FEE_REC_I1 
  ON KSLU_CLU_FEE_REC 
  (RT_DESCR_ID)
/





-----------------------------------------------------------------------------
-- KSLU_CLU_FEE_REC_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_FEE_REC_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_FEE_REC_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_FEE_REC_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_CLU_FEE_REC_ATTR
    ADD CONSTRAINT KSLU_CLU_FEE_REC_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_CLU_FEE_REC_ATTR_I1 
  ON KSLU_CLU_FEE_REC_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSLU_CLU_IDENT
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_IDENT';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_IDENT CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_IDENT
(
      ID VARCHAR2(255)
        , CD VARCHAR2(255)
        , DIV VARCHAR2(255)
        , LVL VARCHAR2(255)
        , LNG_NAME VARCHAR2(255)
        , ORG_ID VARCHAR2(255)
        , SHRT_NAME VARCHAR2(255)
        , ST VARCHAR2(255)
        , SUFX_CD VARCHAR2(255)
        , TYPE VARCHAR2(255)
        , VARTN VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_CLU_IDENT
    ADD CONSTRAINT KSLU_CLU_IDENTP1
PRIMARY KEY (ID)
/







-----------------------------------------------------------------------------
-- KSLU_CLU_IDENT_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_IDENT_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_IDENT_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_IDENT_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/








-----------------------------------------------------------------------------
-- KSLU_CLU_INSTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_INSTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_INSTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_INSTR
(
      ID VARCHAR2(255)
        , ORG_ID VARCHAR2(255)
        , PERS_ID VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_CLU_INSTR
    ADD CONSTRAINT KSLU_CLU_INSTRP1
PRIMARY KEY (ID)
/







-----------------------------------------------------------------------------
-- KSLU_CLU_INSTR_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_INSTR_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_INSTR_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_INSTR_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_CLU_INSTR_ATTR
    ADD CONSTRAINT KSLU_CLU_INSTR_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_CLU_INSTR_ATTR_I1 
  ON KSLU_CLU_INSTR_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSLU_CLU_JN_ACCRED
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_JN_ACCRED';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_JN_ACCRED CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_JN_ACCRED
(
      CLU_ID VARCHAR2(255) NOT NULL
        , CLU_ACCRED_ID VARCHAR2(255) NOT NULL
    
    , CONSTRAINT SYS_C0011436 UNIQUE (CLU_ACCRED_ID)

)
/



CREATE INDEX KSLU_CLU_JN_ACCRED_I1 
  ON KSLU_CLU_JN_ACCRED 
  (CLU_ID)
/





-----------------------------------------------------------------------------
-- KSLU_CLU_JN_CAMP_LOC
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_JN_CAMP_LOC';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_JN_CAMP_LOC CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_JN_CAMP_LOC
(
      ID VARCHAR2(255)
        , CAMP_LOC VARCHAR2(255)
        , CLU_ID VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_CLU_JN_CAMP_LOC
    ADD CONSTRAINT KSLU_CLU_JN_CAMP_LOCP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_CLU_JN_CAMP_LOC_I1 
  ON KSLU_CLU_JN_CAMP_LOC 
  (CLU_ID)
/





-----------------------------------------------------------------------------
-- KSLU_CLU_JN_CLU_IDENT
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_JN_CLU_IDENT';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_JN_CLU_IDENT CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_JN_CLU_IDENT
(
      CLU_ID VARCHAR2(255) NOT NULL
        , ALT_CLU_ID VARCHAR2(255) NOT NULL
    
    , CONSTRAINT SYS_C0011441 UNIQUE (ALT_CLU_ID)

)
/



CREATE INDEX KSLU_CLU_JN_CLU_IDENT_I2 
  ON KSLU_CLU_JN_CLU_IDENT 
  (CLU_ID)
/





-----------------------------------------------------------------------------
-- KSLU_CLU_JN_CLU_INSTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_JN_CLU_INSTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_JN_CLU_INSTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_JN_CLU_INSTR
(
      CLU_ID VARCHAR2(255) NOT NULL
        , CLU_INSTR_ID VARCHAR2(255) NOT NULL
    
    , CONSTRAINT SYS_C0011444 UNIQUE (CLU_INSTR_ID)

)
/



CREATE INDEX KSLU_CLU_JN_CLU_INSTR_I1 
  ON KSLU_CLU_JN_CLU_INSTR 
  (CLU_ID)
/





-----------------------------------------------------------------------------
-- KSLU_CLU_JN_SUBJ_ORG
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_JN_SUBJ_ORG';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_JN_SUBJ_ORG CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_JN_SUBJ_ORG
(
      ID VARCHAR2(255)
        , ORG_ID VARCHAR2(255)
        , CLU_ID VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_CLU_JN_SUBJ_ORG
    ADD CONSTRAINT KSLU_CLU_JN_SUBJ_ORGP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_CLU_JN_SUBJ_ORG_I1 
  ON KSLU_CLU_JN_SUBJ_ORG 
  (CLU_ID)
/





-----------------------------------------------------------------------------
-- KSLU_CLU_LO_ALOW_RELTN_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_LO_ALOW_RELTN_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_LO_ALOW_RELTN_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_LO_ALOW_RELTN_TYPE
(
      ID VARCHAR2(255)
        , CREATEID VARCHAR2(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR2(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR NUMBER(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , LO_TYPE_ID VARCHAR2(255)
        , CLULO_RELTN_TYPE_ID VARCHAR2(255)
        , LU_TYPE_ID VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
    

)
/

ALTER TABLE KSLU_CLU_LO_ALOW_RELTN_TYPE
    ADD CONSTRAINT KSLU_CLU_LO_ALOW_RELTN_TYPEP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_CLU_LO_ALOW_REL_TYPE_I1 
  ON KSLU_CLU_LO_ALOW_RELTN_TYPE 
  (LU_TYPE_ID)
/
CREATE INDEX KSLU_CLU_LO_ALOW_REL_TYPE_I2 
  ON KSLU_CLU_LO_ALOW_RELTN_TYPE 
  (CLULO_RELTN_TYPE_ID)
/





-----------------------------------------------------------------------------
-- KSLU_CLU_LO_RELTN
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_LO_RELTN';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_LO_RELTN CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_LO_RELTN
(
      ID VARCHAR2(255)
        , CREATEID VARCHAR2(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR2(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR NUMBER(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , LO_ID VARCHAR2(255)
        , ST VARCHAR2(255)
        , TYPE VARCHAR2(255)
        , CLU_ID VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
    

)
/

ALTER TABLE KSLU_CLU_LO_RELTN
    ADD CONSTRAINT KSLU_CLU_LO_RELTNP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_CLU_LO_RELTN_I1 
  ON KSLU_CLU_LO_RELTN 
  (CLU_ID)
/
CREATE INDEX KSLU_CLU_LO_RELTN_I2 
  ON KSLU_CLU_LO_RELTN 
  (TYPE)
/





-----------------------------------------------------------------------------
-- KSLU_CLU_LO_RELTN_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_LO_RELTN_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_LO_RELTN_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_LO_RELTN_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_CLU_LO_RELTN_ATTR
    ADD CONSTRAINT KSLU_CLU_LO_RELTN_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_CLU_LO_RELTN_ATTR_I1 
  ON KSLU_CLU_LO_RELTN_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSLU_CLU_LO_RELTN_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_LO_RELTN_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_LO_RELTN_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_LO_RELTN_TYPE
(
      TYPE_KEY VARCHAR2(255)
        , TYPE_DESC VARCHAR2(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_CLU_LO_RELTN_TYPE
    ADD CONSTRAINT KSLU_CLU_LO_RELTN_TYPEP1
PRIMARY KEY (TYPE_KEY)
/







-----------------------------------------------------------------------------
-- KSLU_CLU_LO_RELTN_TYPE_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_LO_RELTN_TYPE_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_LO_RELTN_TYPE_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_LO_RELTN_TYPE_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_CLU_LO_RELTN_TYPE_ATTR
    ADD CONSTRAINT KSLU_CLU_LO_RELTN_TYPE_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_CLU_LO_REL_TYPE_ATTR_I1 
  ON KSLU_CLU_LO_RELTN_TYPE_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSLU_CLU_PUBL
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_PUBL';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_PUBL CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_PUBL
(
      ID VARCHAR2(255)
        , CREATEID VARCHAR2(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR2(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR NUMBER(19) NOT NULL
        , EFF_DT TIMESTAMP
        , END_CYCLE VARCHAR2(255)
        , EXPIR_DT TIMESTAMP
        , START_CYCLE VARCHAR2(255)
        , ST VARCHAR2(255)
        , CLU_ID VARCHAR2(255)
        , CLU_PUB_TYPE_ID VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
    

)
/

ALTER TABLE KSLU_CLU_PUBL
    ADD CONSTRAINT KSLU_CLU_PUBLP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_CLU_PUBL_I1 
  ON KSLU_CLU_PUBL 
  (CLU_ID)
/
CREATE INDEX KSLU_CLU_PUBL_I2 
  ON KSLU_CLU_PUBL 
  (CLU_PUB_TYPE_ID)
/





-----------------------------------------------------------------------------
-- KSLU_CLU_PUBL_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_PUBL_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_PUBL_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_PUBL_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_CLU_PUBL_ATTR
    ADD CONSTRAINT KSLU_CLU_PUBL_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_CLU_PUBL_ATTR_I1 
  ON KSLU_CLU_PUBL_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSLU_CLU_PUBL_JN_CLU_INSTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_PUBL_JN_CLU_INSTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_PUBL_JN_CLU_INSTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_PUBL_JN_CLU_INSTR
(
      CLU_PUBL_ID VARCHAR2(255) NOT NULL
        , CLU_INSTR_ID VARCHAR2(255) NOT NULL
    
    , CONSTRAINT SYS_C009456 UNIQUE (CLU_INSTR_ID)

)
/








-----------------------------------------------------------------------------
-- KSLU_CLU_PUBL_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_PUBL_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_PUBL_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_PUBL_TYPE
(
      TYPE_KEY VARCHAR2(255)
        , TYPE_DESC VARCHAR2(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_CLU_PUBL_TYPE
    ADD CONSTRAINT KSLU_CLU_PUBL_TYPEP1
PRIMARY KEY (TYPE_KEY)
/







-----------------------------------------------------------------------------
-- KSLU_CLU_PUBL_TYPE_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_PUBL_TYPE_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_PUBL_TYPE_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_PUBL_TYPE_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_CLU_PUBL_TYPE_ATTR
    ADD CONSTRAINT KSLU_CLU_PUBL_TYPE_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_CLU_PUBL_TYPE_ATTR_I1 
  ON KSLU_CLU_PUBL_TYPE_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSLU_CLU_PUBL_VARI
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_PUBL_VARI';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_PUBL_VARI CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_PUBL_VARI
(
      ID VARCHAR2(255)
        , VARI_KEY VARCHAR2(255)
        , VARI_VALUE VARCHAR2(2500)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    
    , CONSTRAINT SYS_C0011470 UNIQUE (VARI_KEY, OWNER)

)
/

ALTER TABLE KSLU_CLU_PUBL_VARI
    ADD CONSTRAINT KSLU_CLU_PUBL_VARIP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_CLU_PUBL_VARI_I1 
  ON KSLU_CLU_PUBL_VARI 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSLU_CLU_PUB_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_PUB_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_PUB_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_PUB_TYPE
(
      TYPE_KEY VARCHAR2(255)
        , TYPE_DESC VARCHAR2(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
    

)
/

ALTER TABLE KSLU_CLU_PUB_TYPE
    ADD CONSTRAINT KSLU_CLU_PUB_TYPEP1
PRIMARY KEY (TYPE_KEY)
/







-----------------------------------------------------------------------------
-- KSLU_CLU_PUB_TYPE_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_PUB_TYPE_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_PUB_TYPE_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_PUB_TYPE_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
    

)
/

ALTER TABLE KSLU_CLU_PUB_TYPE_ATTR
    ADD CONSTRAINT KSLU_CLU_PUB_TYPE_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_CLU_PUB_TYPE_ATTR_I1 
  ON KSLU_CLU_PUB_TYPE_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSLU_CLU_RESULT_TYPE_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_RESULT_TYPE_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_RESULT_TYPE_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_RESULT_TYPE_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_CLU_RESULT_TYPE_ATTR
    ADD CONSTRAINT KSLU_CLU_RESULT_TYPE_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_CLU_RESULT_TYPE_ATTR_I1 
  ON KSLU_CLU_RESULT_TYPE_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSLU_CLU_RSLT
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_RSLT';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_RSLT CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_RSLT
(
      ID VARCHAR2(255)
        , CREATEID VARCHAR2(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR2(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR NUMBER(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , ST VARCHAR2(255)
        , CLU_ID VARCHAR2(255)
        , TYPE_KEY_ID VARCHAR2(255)
        , RT_DESCR_ID VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
    

)
/

ALTER TABLE KSLU_CLU_RSLT
    ADD CONSTRAINT KSLU_CLU_RSLTP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_CLU_RSLT_I1 
  ON KSLU_CLU_RSLT 
  (TYPE_KEY_ID)
/
CREATE INDEX KSLU_CLU_RSLT_I2 
  ON KSLU_CLU_RSLT 
  (CLU_ID)
/
CREATE INDEX KSLU_CLU_RSLT_I3 
  ON KSLU_CLU_RSLT 
  (RT_DESCR_ID)
/





-----------------------------------------------------------------------------
-- KSLU_CLU_RSLT_LU_ALOW_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_RSLT_LU_ALOW_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_RSLT_LU_ALOW_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_RSLT_LU_ALOW_TYPE
(
      ID VARCHAR2(255)
        , CREATEID VARCHAR2(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR2(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR NUMBER(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , CLU_RSLT_TYPE_ID VARCHAR2(255)
        , LU_TYPE_ID VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
    

)
/

ALTER TABLE KSLU_CLU_RSLT_LU_ALOW_TYPE
    ADD CONSTRAINT KSLU_CLU_RSLT_LU_ALOW_TYPEP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_CLU_RSLT_LU_ALOW_TYPE_I1 
  ON KSLU_CLU_RSLT_LU_ALOW_TYPE 
  (CLU_RSLT_TYPE_ID)
/
CREATE INDEX KSLU_CLU_RSLT_LU_ALOW_TYPE_I2 
  ON KSLU_CLU_RSLT_LU_ALOW_TYPE 
  (LU_TYPE_ID)
/





-----------------------------------------------------------------------------
-- KSLU_CLU_RSLT_TYP
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_RSLT_TYP';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_RSLT_TYP CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_RSLT_TYP
(
      TYPE_KEY VARCHAR2(255)
        , TYPE_DESC VARCHAR2(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_CLU_RSLT_TYP
    ADD CONSTRAINT KSLU_CLU_RSLT_TYPP1
PRIMARY KEY (TYPE_KEY)
/







-----------------------------------------------------------------------------
-- KSLU_CLU_SET
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_SET';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_SET CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_SET
(
      ID VARCHAR2(255)
        , CREATEID VARCHAR2(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR2(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR NUMBER(19) NOT NULL
        , ADMIN_ORG_ID VARCHAR2(255)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , REFERENCEABLE NUMBER(1)
        , REUSABLE NUMBER(1)
        , NAME VARCHAR2(255)
        , ST VARCHAR2(255)
        , TYPE VARCHAR2(255)
        , RT_DESCR_ID VARCHAR2(255)
        , MEM_QUERY_ID VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
    

)
/

ALTER TABLE KSLU_CLU_SET
    ADD CONSTRAINT KSLU_CLU_SETP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_CLU_SET_I1 
  ON KSLU_CLU_SET 
  (MEM_QUERY_ID)
/
CREATE INDEX KSLU_CLU_SET_I2 
  ON KSLU_CLU_SET 
  (RT_DESCR_ID)
/





-----------------------------------------------------------------------------
-- KSLU_CLU_SET_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_SET_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_SET_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_SET_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_CLU_SET_ATTR
    ADD CONSTRAINT KSLU_CLU_SET_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_CLU_SET_ATTR_I1 
  ON KSLU_CLU_SET_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSLU_CLU_SET_JN_CLU
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_SET_JN_CLU';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_SET_JN_CLU CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_SET_JN_CLU
(
      CLU_SET_ID VARCHAR2(255) NOT NULL
        , CLU_VER_IND_ID VARCHAR2(255) NOT NULL
        , ID VARCHAR2(255)
        , VER_NBR NUMBER(19)
        , OBJ_ID VARCHAR2(36)
    
    , CONSTRAINT KSLU_CLU_SET_JN_CLU_I1 UNIQUE (CLU_SET_ID, CLU_VER_IND_ID)

)
/

ALTER TABLE KSLU_CLU_SET_JN_CLU
    ADD CONSTRAINT KSLU_CLU_SET_JN_CLUP1
PRIMARY KEY (ID)
/







-----------------------------------------------------------------------------
-- KSLU_CLU_SET_JN_CLU_SET
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_SET_JN_CLU_SET';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_SET_JN_CLU_SET CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_SET_JN_CLU_SET
(
      CLU_SET_PARENT_ID VARCHAR2(255) NOT NULL
        , CLU_SET_CHILD_ID VARCHAR2(255) NOT NULL
    

)
/



CREATE INDEX KSLU_CLU_SET_JN_CLU_SET_I1 
  ON KSLU_CLU_SET_JN_CLU_SET 
  (CLU_SET_PARENT_ID)
/
CREATE INDEX KSLU_CLU_SET_JN_CLU_SET_I2 
  ON KSLU_CLU_SET_JN_CLU_SET 
  (CLU_SET_CHILD_ID)
/





-----------------------------------------------------------------------------
-- KSLU_CLU_SET_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_SET_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_SET_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_SET_TYPE
(
      TYPE_KEY VARCHAR2(255)
        , TYPE_DESC VARCHAR2(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_CLU_SET_TYPE
    ADD CONSTRAINT KSLU_CLU_SET_TYPEP1
PRIMARY KEY (TYPE_KEY)
/







-----------------------------------------------------------------------------
-- KSLU_CLU_SET_TYPE_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_CLU_SET_TYPE_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_CLU_SET_TYPE_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_CLU_SET_TYPE_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_CLU_SET_TYPE_ATTR
    ADD CONSTRAINT KSLU_CLU_SET_TYPE_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_CLU_SET_TYPE_ATTR_I1 
  ON KSLU_CLU_SET_TYPE_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSLU_DLVMTHD_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_DLVMTHD_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_DLVMTHD_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_DLVMTHD_TYPE
(
      TYPE_KEY VARCHAR2(255)
        , TYPE_DESC VARCHAR2(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_DLVMTHD_TYPE
    ADD CONSTRAINT KSLU_DLVMTHD_TYPEP1
PRIMARY KEY (TYPE_KEY)
/







-----------------------------------------------------------------------------
-- KSLU_DLVMTHD_TYPE_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_DLVMTHD_TYPE_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_DLVMTHD_TYPE_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_DLVMTHD_TYPE_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_DLVMTHD_TYPE_ATTR
    ADD CONSTRAINT KSLU_DLVMTHD_TYPE_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_DLVMTHD_TYPE_ATTR_I1 
  ON KSLU_DLVMTHD_TYPE_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSLU_INSTFRMT_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_INSTFRMT_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_INSTFRMT_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_INSTFRMT_TYPE
(
      TYPE_KEY VARCHAR2(255)
        , TYPE_DESC VARCHAR2(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_INSTFRMT_TYPE
    ADD CONSTRAINT KSLU_INSTFRMT_TYPEP1
PRIMARY KEY (TYPE_KEY)
/







-----------------------------------------------------------------------------
-- KSLU_INSTFRMT_TYPE_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_INSTFRMT_TYPE_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_INSTFRMT_TYPE_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_INSTFRMT_TYPE_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_INSTFRMT_TYPE_ATTR
    ADD CONSTRAINT KSLU_INSTFRMT_TYPE_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_INSTFRMT_TYPE_ATTR_I1 
  ON KSLU_INSTFRMT_TYPE_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSLU_LUI
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_LUI';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_LUI CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_LUI
(
      ID VARCHAR2(255)
        , CREATEID VARCHAR2(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR2(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR NUMBER(19) NOT NULL
        , ATP_ID VARCHAR2(255)
        , EFF_DT TIMESTAMP
        , EXP_DT TIMESTAMP
        , LUI_CODE VARCHAR2(255)
        , MAX_SEATS NUMBER(10)
        , ST VARCHAR2(255)
        , CLU_ID VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
    

)
/

ALTER TABLE KSLU_LUI
    ADD CONSTRAINT KSLU_LUIP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_LUI_I1 
  ON KSLU_LUI 
  (CLU_ID)
/





-----------------------------------------------------------------------------
-- KSLU_LUILUI_RELTN
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_LUILUI_RELTN';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_LUILUI_RELTN CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_LUILUI_RELTN
(
      ID VARCHAR2(255)
        , CREATEID VARCHAR2(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR2(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR NUMBER(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , ST VARCHAR2(255)
        , LULU_RELTN_TYPE_ID VARCHAR2(255)
        , LUI_ID VARCHAR2(255)
        , RELATED_LUI_ID VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
    

)
/

ALTER TABLE KSLU_LUILUI_RELTN
    ADD CONSTRAINT KSLU_LUILUI_RELTNP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_LUILUI_RELTN_I1 
  ON KSLU_LUILUI_RELTN 
  (RELATED_LUI_ID)
/
CREATE INDEX KSLU_LUILUI_RELTN_I2 
  ON KSLU_LUILUI_RELTN 
  (LULU_RELTN_TYPE_ID)
/
CREATE INDEX KSLU_LUILUI_RELTN_I3 
  ON KSLU_LUILUI_RELTN 
  (LUI_ID)
/





-----------------------------------------------------------------------------
-- KSLU_LUILUI_RELTN_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_LUILUI_RELTN_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_LUILUI_RELTN_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_LUILUI_RELTN_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_LUILUI_RELTN_ATTR
    ADD CONSTRAINT KSLU_LUILUI_RELTN_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_LUILUI_RELTN_ATTR_I1 
  ON KSLU_LUILUI_RELTN_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSLU_LUI_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_LUI_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_LUI_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_LUI_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_LUI_ATTR
    ADD CONSTRAINT KSLU_LUI_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_LUI_ATTR_I1 
  ON KSLU_LUI_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSLU_LULU_RELTN_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_LULU_RELTN_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_LULU_RELTN_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_LULU_RELTN_TYPE
(
      ID VARCHAR2(255)
        , CREATEID VARCHAR2(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR2(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR NUMBER(19) NOT NULL
        , DESCR VARCHAR2(255)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , REV_DESC VARCHAR2(255)
        , REV_NAME VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
    

)
/

ALTER TABLE KSLU_LULU_RELTN_TYPE
    ADD CONSTRAINT KSLU_LULU_RELTN_TYPEP1
PRIMARY KEY (ID)
/







-----------------------------------------------------------------------------
-- KSLU_LULU_RELTN_TYPE_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_LULU_RELTN_TYPE_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_LULU_RELTN_TYPE_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_LULU_RELTN_TYPE_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_LULU_RELTN_TYPE_ATTR
    ADD CONSTRAINT KSLU_LULU_RELTN_TYPE_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_LULU_RELTN_TYPE_ATTR_I1 
  ON KSLU_LULU_RELTN_TYPE_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSLU_LULU_RELTN_TYPE_JN_LU_TYP
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_LULU_RELTN_TYPE_JN_LU_TYP';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_LULU_RELTN_TYPE_JN_LU_TYP CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_LULU_RELTN_TYPE_JN_LU_TYP
(
      LULU_RELTN_TYPE_ID VARCHAR2(255) NOT NULL
        , LU_TYPE_ID VARCHAR2(255) NOT NULL
    

)
/



CREATE INDEX KSLU_LULU_RELTYP_JN_LUTYP_I1 
  ON KSLU_LULU_RELTN_TYPE_JN_LU_TYP 
  (LULU_RELTN_TYPE_ID)
/
CREATE INDEX KSLU_LULU_RELTYP_JN_LUTYP_I2 
  ON KSLU_LULU_RELTN_TYPE_JN_LU_TYP 
  (LU_TYPE_ID)
/





-----------------------------------------------------------------------------
-- KSLU_LUTYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_LUTYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_LUTYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_LUTYPE
(
      TYPE_KEY VARCHAR2(255)
        , TYPE_DESC VARCHAR2(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , DLVR_MTHD VARCHAR2(255)
        , INSTR_FRMT VARCHAR2(255)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_LUTYPE
    ADD CONSTRAINT KSLU_LUTYPEP1
PRIMARY KEY (TYPE_KEY)
/







-----------------------------------------------------------------------------
-- KSLU_LU_CD_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_LU_CD_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_LU_CD_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_LU_CD_TYPE
(
      TYPE_KEY VARCHAR2(255)
        , TYPE_DESC VARCHAR2(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_LU_CD_TYPE
    ADD CONSTRAINT KSLU_LU_CD_TYPEP1
PRIMARY KEY (TYPE_KEY)
/







-----------------------------------------------------------------------------
-- KSLU_LU_CD_TYPE_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_LU_CD_TYPE_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_LU_CD_TYPE_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_LU_CD_TYPE_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_LU_CD_TYPE_ATTR
    ADD CONSTRAINT KSLU_LU_CD_TYPE_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_LU_CD_TYPE_ATTR_I1 
  ON KSLU_LU_CD_TYPE_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSLU_LU_CODE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_LU_CODE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_LU_CODE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_LU_CODE
(
      ID VARCHAR2(255)
        , CREATEID VARCHAR2(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR2(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR NUMBER(19) NOT NULL
        , DESCR VARCHAR2(255)
        , TYPE VARCHAR2(255)
        , VALUE VARCHAR2(255)
        , CLU_ID VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
    

)
/

ALTER TABLE KSLU_LU_CODE
    ADD CONSTRAINT KSLU_LU_CODEP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_LU_CODE_I1 
  ON KSLU_LU_CODE 
  (CLU_ID)
/





-----------------------------------------------------------------------------
-- KSLU_LU_CODE_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_LU_CODE_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_LU_CODE_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_LU_CODE_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_LU_CODE_ATTR
    ADD CONSTRAINT KSLU_LU_CODE_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_LU_CODE_ATTR_I1 
  ON KSLU_LU_CODE_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSLU_LU_LU_ALOW_RELTN_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_LU_LU_ALOW_RELTN_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_LU_LU_ALOW_RELTN_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_LU_LU_ALOW_RELTN_TYPE
(
      ID VARCHAR2(255)
        , CREATEID VARCHAR2(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR2(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR NUMBER(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , LU_TYPE_ID VARCHAR2(255)
        , LU_REL_TYPE_ID VARCHAR2(255)
        , LU_LU_RELTN_TYPE_ID VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
    

)
/

ALTER TABLE KSLU_LU_LU_ALOW_RELTN_TYPE
    ADD CONSTRAINT KSLU_LU_LU_ALOW_RELTN_TYPEP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_LU_LU_ALOW_RELTN_TYPE_I1 
  ON KSLU_LU_LU_ALOW_RELTN_TYPE 
  (LU_REL_TYPE_ID)
/
CREATE INDEX KSLU_LU_LU_ALOW_RELTN_TYPE_I2 
  ON KSLU_LU_LU_ALOW_RELTN_TYPE 
  (LU_LU_RELTN_TYPE_ID)
/
CREATE INDEX KSLU_LU_LU_ALOW_RELTN_TYPE_I3 
  ON KSLU_LU_LU_ALOW_RELTN_TYPE 
  (LU_TYPE_ID)
/





-----------------------------------------------------------------------------
-- KSLU_LU_PUBL_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_LU_PUBL_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_LU_PUBL_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_LU_PUBL_TYPE
(
      TYPE_KEY VARCHAR2(255)
        , TYPE_DESC VARCHAR2(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_LU_PUBL_TYPE
    ADD CONSTRAINT KSLU_LU_PUBL_TYPEP1
PRIMARY KEY (TYPE_KEY)
/







-----------------------------------------------------------------------------
-- KSLU_LU_PUBL_TYPE_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_LU_PUBL_TYPE_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_LU_PUBL_TYPE_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_LU_PUBL_TYPE_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_LU_PUBL_TYPE_ATTR
    ADD CONSTRAINT KSLU_LU_PUBL_TYPE_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_LU_PUBL_TYPE_ATTR_I1 
  ON KSLU_LU_PUBL_TYPE_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSLU_LU_TYPE_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_LU_TYPE_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_LU_TYPE_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_LU_TYPE_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_LU_TYPE_ATTR
    ADD CONSTRAINT KSLU_LU_TYPE_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_LU_TYPE_ATTR_I1 
  ON KSLU_LU_TYPE_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSLU_MEMSHIP
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_MEMSHIP';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_MEMSHIP CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_MEMSHIP
(
      ID VARCHAR2(255)
        , SEARCH_TYPE_KEY VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_MEMSHIP
    ADD CONSTRAINT KSLU_MEMSHIPP1
PRIMARY KEY (ID)
/







-----------------------------------------------------------------------------
-- KSLU_MEMSHIP_KSLU_SPARAM
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_MEMSHIP_KSLU_SPARAM';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_MEMSHIP_KSLU_SPARAM CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_MEMSHIP_KSLU_SPARAM
(
      KSLU_MEMSHIP_ID VARCHAR2(255) NOT NULL
        , SEARCHPARAMETERS_ID VARCHAR2(255) NOT NULL
    
    , CONSTRAINT SYS_C0011543 UNIQUE (SEARCHPARAMETERS_ID)

)
/



CREATE INDEX KSLU_MEMSHIP_KSLU_SPARAM_I1 
  ON KSLU_MEMSHIP_KSLU_SPARAM 
  (KSLU_MEMSHIP_ID)
/





-----------------------------------------------------------------------------
-- KSLU_RICH_TEXT_T
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_RICH_TEXT_T';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_RICH_TEXT_T CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_RICH_TEXT_T
(
      ID VARCHAR2(255)
        , FORMATTED VARCHAR2(2000)
        , PLAIN VARCHAR2(4000)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_RICH_TEXT_T
    ADD CONSTRAINT KSLU_RICH_TEXT_TP1
PRIMARY KEY (ID)
/







-----------------------------------------------------------------------------
-- KSLU_RSLTUSAGE_LU_ALOW_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_RSLTUSAGE_LU_ALOW_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_RSLTUSAGE_LU_ALOW_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_RSLTUSAGE_LU_ALOW_TYPE
(
      ID VARCHAR2(255)
        , CREATEID VARCHAR2(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR2(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR NUMBER(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , LU_TYPE_ID VARCHAR2(255)
        , CLU_RSLT_USAGE_TYPE_ID VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
    

)
/

ALTER TABLE KSLU_RSLTUSAGE_LU_ALOW_TYPE
    ADD CONSTRAINT KSLU_RSLTUSAGE_LU_ALOW_TYPEP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_RSLTUSAGE_LU_ALOW_TYP_I1 
  ON KSLU_RSLTUSAGE_LU_ALOW_TYPE 
  (CLU_RSLT_USAGE_TYPE_ID)
/
CREATE INDEX KSLU_RSLTUSAGE_LU_ALOW_TYP_I2 
  ON KSLU_RSLTUSAGE_LU_ALOW_TYPE 
  (LU_TYPE_ID)
/





-----------------------------------------------------------------------------
-- KSLU_RSLT_COMP_USG_ALOW_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_RSLT_COMP_USG_ALOW_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_RSLT_COMP_USG_ALOW_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_RSLT_COMP_USG_ALOW_TYPE
(
      ID VARCHAR2(255)
        , CREATEID VARCHAR2(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR2(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR NUMBER(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , RSLT_COMP_ID VARCHAR2(255)
        , RSLT_USG_TYPE_ID VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
    

)
/

ALTER TABLE KSLU_RSLT_COMP_USG_ALOW_TYPE
    ADD CONSTRAINT KSLU_RSLT_COMP_USG_ALOW_TYPP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_RSLTCOMP_USG_ALOW_TYP_I1 
  ON KSLU_RSLT_COMP_USG_ALOW_TYPE 
  (RSLT_USG_TYPE_ID)
/





-----------------------------------------------------------------------------
-- KSLU_RSLT_OPT
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_RSLT_OPT';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_RSLT_OPT CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_RSLT_OPT
(
      ID VARCHAR2(255)
        , CREATEID VARCHAR2(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR2(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR NUMBER(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , RES_COMP_ID VARCHAR2(255)
        , ST VARCHAR2(255)
        , RT_DESCR_ID VARCHAR2(255)
        , RES_USAGE_ID VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
    

)
/

ALTER TABLE KSLU_RSLT_OPT
    ADD CONSTRAINT KSLU_RSLT_OPTP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_RSLT_OPT_I1 
  ON KSLU_RSLT_OPT 
  (RES_USAGE_ID)
/
CREATE INDEX KSLU_RSLT_OPT_I2 
  ON KSLU_RSLT_OPT 
  (RT_DESCR_ID)
/





-----------------------------------------------------------------------------
-- KSLU_RSLT_USG_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_RSLT_USG_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_RSLT_USG_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_RSLT_USG_TYPE
(
      TYPE_KEY VARCHAR2(255)
        , TYPE_DESC VARCHAR2(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_RSLT_USG_TYPE
    ADD CONSTRAINT KSLU_RSLT_USG_TYPEP1
PRIMARY KEY (TYPE_KEY)
/







-----------------------------------------------------------------------------
-- KSLU_RSLT_USG_TYPE_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_RSLT_USG_TYPE_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_RSLT_USG_TYPE_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_RSLT_USG_TYPE_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_RSLT_USG_TYPE_ATTR
    ADD CONSTRAINT KSLU_RSLT_USG_TYPE_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_RSLT_USG_TYPE_ATTR_I1 
  ON KSLU_RSLT_USG_TYPE_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSLU_RSRC
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_RSRC';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_RSRC CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_RSRC
(
      ID VARCHAR2(255)
        , RSRC_TYPE_ID VARCHAR2(255)
        , CLU_ID VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    
    , CONSTRAINT SYS_C0011561 UNIQUE (RSRC_TYPE_ID, CLU_ID)

)
/

ALTER TABLE KSLU_RSRC
    ADD CONSTRAINT KSLU_RSRCP1
PRIMARY KEY (ID)
/


CREATE INDEX KSLU_RSRC_I1 
  ON KSLU_RSRC 
  (CLU_ID)
/





-----------------------------------------------------------------------------
-- KSLU_SPARAM
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_SPARAM';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_SPARAM CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_SPARAM
(
      ID VARCHAR2(255)
        , SEARCH_PARAM_KEY VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_SPARAM
    ADD CONSTRAINT KSLU_SPARAMP1
PRIMARY KEY (ID)
/







-----------------------------------------------------------------------------
-- KSLU_SPARAM_KSLU_SPVALUE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_SPARAM_KSLU_SPVALUE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_SPARAM_KSLU_SPVALUE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_SPARAM_KSLU_SPVALUE
(
      KSLU_SPARAM_ID VARCHAR2(255) NOT NULL
        , VALUES_ID VARCHAR2(255) NOT NULL
    
    , CONSTRAINT SYS_C0011566 UNIQUE (VALUES_ID)

)
/



CREATE INDEX KSLU_SPARAM_KSLU_SPVALUE_I1 
  ON KSLU_SPARAM_KSLU_SPVALUE 
  (KSLU_SPARAM_ID)
/





-----------------------------------------------------------------------------
-- KSLU_SPVALUE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSLU_SPVALUE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSLU_SPVALUE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSLU_SPVALUE
(
      ID VARCHAR2(255)
        , VALUE VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSLU_SPVALUE
    ADD CONSTRAINT KSLU_SPVALUEP1
PRIMARY KEY (ID)
/







-----------------------------------------------------------------------------
-- KSMG_MESSAGE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSMG_MESSAGE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSMG_MESSAGE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSMG_MESSAGE
(
      ID VARCHAR2(255)
        , MSG_ID VARCHAR2(255)
        , LOCALE VARCHAR2(255)
        , GRP_NAME VARCHAR2(255)
        , MSG_VALUE VARCHAR2(2000)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSMG_MESSAGE
    ADD CONSTRAINT KSMG_MESSAGEP1
PRIMARY KEY (ID)
/







-----------------------------------------------------------------------------
-- KSOR_ORG
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSOR_ORG';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSOR_ORG CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSOR_ORG
(
      ID VARCHAR2(255)
        , CREATEID VARCHAR2(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR2(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR NUMBER(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , LNG_DESCR VARCHAR2(2000)
        , LNG_NAME VARCHAR2(255)
        , SHRT_DESCR VARCHAR2(500)
        , SHRT_NAME VARCHAR2(255)
        , ST VARCHAR2(255)
        , TYPE VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
    

)
/

ALTER TABLE KSOR_ORG
    ADD CONSTRAINT KSOR_ORGP1
PRIMARY KEY (ID)
/


CREATE INDEX KSOR_ORG_I1 
  ON KSOR_ORG 
  (TYPE)
/





-----------------------------------------------------------------------------
-- KSOR_ORG_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSOR_ORG_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSOR_ORG_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSOR_ORG_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSOR_ORG_ATTR
    ADD CONSTRAINT KSOR_ORG_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSOR_ORG_ATTR_I1 
  ON KSOR_ORG_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSOR_ORG_HIRCHY
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSOR_ORG_HIRCHY';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSOR_ORG_HIRCHY CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSOR_ORG_HIRCHY
(
      ID VARCHAR2(255)
        , DESCR VARCHAR2(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , ROOT_ORG VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSOR_ORG_HIRCHY
    ADD CONSTRAINT KSOR_ORG_HIRCHYP1
PRIMARY KEY (ID)
/


CREATE INDEX KSOR_ORG_HIRCHY_I1 
  ON KSOR_ORG_HIRCHY 
  (ROOT_ORG)
/





-----------------------------------------------------------------------------
-- KSOR_ORG_HIRCHY_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSOR_ORG_HIRCHY_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSOR_ORG_HIRCHY_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSOR_ORG_HIRCHY_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSOR_ORG_HIRCHY_ATTR
    ADD CONSTRAINT KSOR_ORG_HIRCHY_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSOR_ORG_HIRCHY_ATTR_I1 
  ON KSOR_ORG_HIRCHY_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSOR_ORG_HIRCHY_JN_ORG_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSOR_ORG_HIRCHY_JN_ORG_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSOR_ORG_HIRCHY_JN_ORG_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSOR_ORG_HIRCHY_JN_ORG_TYPE
(
      ORG_HIRCHY_ID VARCHAR2(255) NOT NULL
        , ORG_TYPE_ID VARCHAR2(255) NOT NULL
    

)
/



CREATE INDEX KSOR_ORG_HIRCHY_JN_ORG_TYP_I1 
  ON KSOR_ORG_HIRCHY_JN_ORG_TYPE 
  (ORG_HIRCHY_ID)
/
CREATE INDEX KSOR_ORG_HIRCHY_JN_ORG_TYP_I2 
  ON KSOR_ORG_HIRCHY_JN_ORG_TYPE 
  (ORG_TYPE_ID)
/





-----------------------------------------------------------------------------
-- KSOR_ORG_JN_ORG_PERS_REL_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSOR_ORG_JN_ORG_PERS_REL_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSOR_ORG_JN_ORG_PERS_REL_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSOR_ORG_JN_ORG_PERS_REL_TYPE
(
      ORG_ID VARCHAR2(255) NOT NULL
        , ORG_PERS_RELTN_TYPE_ID VARCHAR2(255) NOT NULL
    

)
/



CREATE INDEX KSOR_ORG_JN_ORG_PERREL_TYP_I1 
  ON KSOR_ORG_JN_ORG_PERS_REL_TYPE 
  (ORG_PERS_RELTN_TYPE_ID)
/
CREATE INDEX KSOR_ORG_JN_ORG_PERREL_TYP_I2 
  ON KSOR_ORG_JN_ORG_PERS_REL_TYPE 
  (ORG_ID)
/





-----------------------------------------------------------------------------
-- KSOR_ORG_ORG_RELTN
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSOR_ORG_ORG_RELTN';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSOR_ORG_ORG_RELTN CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSOR_ORG_ORG_RELTN
(
      ID VARCHAR2(255)
        , CREATEID VARCHAR2(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR2(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR NUMBER(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , ST VARCHAR2(255)
        , ORG VARCHAR2(255)
        , RELATED_ORG VARCHAR2(255)
        , TYPE VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
    

)
/

ALTER TABLE KSOR_ORG_ORG_RELTN
    ADD CONSTRAINT KSOR_ORG_ORG_RELTNP1
PRIMARY KEY (ID)
/


CREATE INDEX KSOR_ORG_ORG_RELTN_I1 
  ON KSOR_ORG_ORG_RELTN 
  (ORG)
/
CREATE INDEX KSOR_ORG_ORG_RELTN_I2 
  ON KSOR_ORG_ORG_RELTN 
  (RELATED_ORG)
/
CREATE INDEX KSOR_ORG_ORG_RELTN_I3 
  ON KSOR_ORG_ORG_RELTN 
  (TYPE)
/





-----------------------------------------------------------------------------
-- KSOR_ORG_ORG_RELTN_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSOR_ORG_ORG_RELTN_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSOR_ORG_ORG_RELTN_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSOR_ORG_ORG_RELTN_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSOR_ORG_ORG_RELTN_ATTR
    ADD CONSTRAINT KSOR_ORG_ORG_RELTN_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSOR_ORG_ORG_RELTN_ATTR_I1 
  ON KSOR_ORG_ORG_RELTN_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSOR_ORG_ORG_RELTN_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSOR_ORG_ORG_RELTN_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSOR_ORG_ORG_RELTN_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSOR_ORG_ORG_RELTN_TYPE
(
      TYPE_KEY VARCHAR2(255)
        , TYPE_DESC VARCHAR2(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , REV_DESCR VARCHAR2(255)
        , REV_NAME VARCHAR2(255)
        , ORG_HIRCHY VARCHAR2(255)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSOR_ORG_ORG_RELTN_TYPE
    ADD CONSTRAINT KSOR_ORG_ORG_RELTN_TYPEP1
PRIMARY KEY (TYPE_KEY)
/


CREATE INDEX KSOR_ORG_ORG_RELTN_TYPE_I1 
  ON KSOR_ORG_ORG_RELTN_TYPE 
  (ORG_HIRCHY)
/





-----------------------------------------------------------------------------
-- KSOR_ORG_ORG_RELTN_TYPE_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSOR_ORG_ORG_RELTN_TYPE_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSOR_ORG_ORG_RELTN_TYPE_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSOR_ORG_ORG_RELTN_TYPE_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSOR_ORG_ORG_RELTN_TYPE_ATTR
    ADD CONSTRAINT KSOR_ORG_ORG_RELTN_TYPE_ATTP1
PRIMARY KEY (ID)
/


CREATE INDEX KSOR_ORG_ORG_REL_TYP_ATTR_I1 
  ON KSOR_ORG_ORG_RELTN_TYPE_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSOR_ORG_PERS_RELTN
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSOR_ORG_PERS_RELTN';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSOR_ORG_PERS_RELTN CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSOR_ORG_PERS_RELTN
(
      ID VARCHAR2(255)
        , CREATEID VARCHAR2(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR2(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR NUMBER(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , PERS_ID VARCHAR2(255)
        , ST VARCHAR2(255)
        , ORG VARCHAR2(255)
        , ORG_PERS_RELTN_TYPE VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
    
    , CONSTRAINT SYS_C0011691 UNIQUE (ORG_PERS_RELTN_TYPE, ORG, PERS_ID)

)
/

ALTER TABLE KSOR_ORG_PERS_RELTN
    ADD CONSTRAINT KSOR_ORG_PERS_RELTNP1
PRIMARY KEY (ID)
/


CREATE INDEX KSOR_ORG_PERS_RELTN_I1 
  ON KSOR_ORG_PERS_RELTN 
  (ORG)
/
CREATE INDEX KSOR_ORG_PERS_RELTN_I2 
  ON KSOR_ORG_PERS_RELTN 
  (ORG_PERS_RELTN_TYPE)
/





-----------------------------------------------------------------------------
-- KSOR_ORG_PERS_RELTN_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSOR_ORG_PERS_RELTN_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSOR_ORG_PERS_RELTN_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSOR_ORG_PERS_RELTN_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSOR_ORG_PERS_RELTN_ATTR
    ADD CONSTRAINT KSOR_ORG_PERS_RELTN_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSOR_ORG_PERS_RELTN_ATTR_I1 
  ON KSOR_ORG_PERS_RELTN_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSOR_ORG_PERS_RELTN_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSOR_ORG_PERS_RELTN_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSOR_ORG_PERS_RELTN_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSOR_ORG_PERS_RELTN_TYPE
(
      TYPE_KEY VARCHAR2(255)
        , TYPE_DESC VARCHAR2(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSOR_ORG_PERS_RELTN_TYPE
    ADD CONSTRAINT KSOR_ORG_PERS_RELTN_TYPEP1
PRIMARY KEY (TYPE_KEY)
/







-----------------------------------------------------------------------------
-- KSOR_ORG_PERS_RELTN_TYPE_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSOR_ORG_PERS_RELTN_TYPE_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSOR_ORG_PERS_RELTN_TYPE_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSOR_ORG_PERS_RELTN_TYPE_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSOR_ORG_PERS_RELTN_TYPE_ATTR
    ADD CONSTRAINT KSOR_ORG_PERS_RELTN_TYPE_ATP1
PRIMARY KEY (ID)
/


CREATE INDEX KSOR_ORG_PERS_REL_TYP_ATTR_I1 
  ON KSOR_ORG_PERS_RELTN_TYPE_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSOR_ORG_POS_RESTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSOR_ORG_POS_RESTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSOR_ORG_POS_RESTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSOR_ORG_POS_RESTR
(
      ID VARCHAR2(255)
        , CREATEID VARCHAR2(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR2(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR NUMBER(19) NOT NULL
        , DESCR VARCHAR2(2000)
        , MAX_NUM_RELTN VARCHAR2(255)
        , MIN_NUM_RELTN NUMBER(10)
        , ATP_DUR_TYP_KEY VARCHAR2(255)
        , TM_QUANTITY NUMBER(10)
        , TTL VARCHAR2(255)
        , ORG VARCHAR2(255)
        , PERS_RELTN_TYPE VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
    
    , CONSTRAINT SYS_C0011701 UNIQUE (ORG, PERS_RELTN_TYPE)

)
/

ALTER TABLE KSOR_ORG_POS_RESTR
    ADD CONSTRAINT KSOR_ORG_POS_RESTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSOR_ORG_POS_RESTR_I1 
  ON KSOR_ORG_POS_RESTR 
  (PERS_RELTN_TYPE)
/
CREATE INDEX KSOR_ORG_POS_RESTR_I2 
  ON KSOR_ORG_POS_RESTR 
  (ORG)
/





-----------------------------------------------------------------------------
-- KSOR_ORG_POS_RESTR_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSOR_ORG_POS_RESTR_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSOR_ORG_POS_RESTR_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSOR_ORG_POS_RESTR_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSOR_ORG_POS_RESTR_ATTR
    ADD CONSTRAINT KSOR_ORG_POS_RESTR_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSOR_ORG_POS_RESTR_ATTR_I1 
  ON KSOR_ORG_POS_RESTR_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSOR_ORG_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSOR_ORG_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSOR_ORG_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSOR_ORG_TYPE
(
      TYPE_KEY VARCHAR2(255)
        , TYPE_DESC VARCHAR2(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSOR_ORG_TYPE
    ADD CONSTRAINT KSOR_ORG_TYPEP1
PRIMARY KEY (TYPE_KEY)
/







-----------------------------------------------------------------------------
-- KSOR_ORG_TYPE_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSOR_ORG_TYPE_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSOR_ORG_TYPE_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSOR_ORG_TYPE_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSOR_ORG_TYPE_ATTR
    ADD CONSTRAINT KSOR_ORG_TYPE_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSOR_ORG_TYPE_ATTR_I1 
  ON KSOR_ORG_TYPE_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSOR_ORG_TYPE_JN_ORG_PERRL_TYP
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSOR_ORG_TYPE_JN_ORG_PERRL_TYP';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSOR_ORG_TYPE_JN_ORG_PERRL_TYP CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSOR_ORG_TYPE_JN_ORG_PERRL_TYP
(
      ORG_TYPE_ID VARCHAR2(255) NOT NULL
        , ORG_PERS_RELTN_TYPE_ID VARCHAR2(255) NOT NULL
    

)
/



CREATE INDEX KSOR_ORGTYP_JN_ORGPREL_TYP_I1 
  ON KSOR_ORG_TYPE_JN_ORG_PERRL_TYP 
  (ORG_PERS_RELTN_TYPE_ID)
/
CREATE INDEX KSOR_ORGTYP_JN_ORGPREL_TYP_I2 
  ON KSOR_ORG_TYPE_JN_ORG_PERRL_TYP 
  (ORG_TYPE_ID)
/





-----------------------------------------------------------------------------
-- KSPR_PROPOSAL
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSPR_PROPOSAL';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSPR_PROPOSAL CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSPR_PROPOSAL
(
      PROPOSAL_ID VARCHAR2(255)
        , CREATEID VARCHAR2(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR2(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR NUMBER(19) NOT NULL
        , DETAIL_DESC VARCHAR2(255)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , RATIONALE VARCHAR2(255)
        , STATE VARCHAR2(255)
        , WORKFLOW_ID VARCHAR2(255)
        , TYPE VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
    

)
/

ALTER TABLE KSPR_PROPOSAL
    ADD CONSTRAINT KSPR_PROPOSALP1
PRIMARY KEY (PROPOSAL_ID)
/


CREATE INDEX KSPR_PROPOSAL_I1 
  ON KSPR_PROPOSAL 
  (TYPE)
/





-----------------------------------------------------------------------------
-- KSPR_PROPOSAL_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSPR_PROPOSAL_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSPR_PROPOSAL_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSPR_PROPOSAL_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSPR_PROPOSAL_ATTR
    ADD CONSTRAINT KSPR_PROPOSAL_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSPR_PROPOSAL_ATTR_I1 
  ON KSPR_PROPOSAL_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSPR_PROPOSAL_JN_ORG
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSPR_PROPOSAL_JN_ORG';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSPR_PROPOSAL_JN_ORG CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSPR_PROPOSAL_JN_ORG
(
      ORGREF_ID VARCHAR2(255)
        , ORG_ID VARCHAR2(255)
        , PROPOSAL_ID VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSPR_PROPOSAL_JN_ORG
    ADD CONSTRAINT KSPR_PROPOSAL_JN_ORGP1
PRIMARY KEY (ORGREF_ID)
/


CREATE INDEX KSPR_PROPOSAL_JN_ORG_I1 
  ON KSPR_PROPOSAL_JN_ORG 
  (PROPOSAL_ID)
/





-----------------------------------------------------------------------------
-- KSPR_PROPOSAL_JN_PERSON
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSPR_PROPOSAL_JN_PERSON';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSPR_PROPOSAL_JN_PERSON CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSPR_PROPOSAL_JN_PERSON
(
      ID VARCHAR2(255)
        , PERSONREF_ID VARCHAR2(255)
        , PROPOSAL_ID VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSPR_PROPOSAL_JN_PERSON
    ADD CONSTRAINT KSPR_PROPOSAL_JN_PERSONP1
PRIMARY KEY (ID)
/


CREATE INDEX KSPR_PROPOSAL_JN_PERSON_I1 
  ON KSPR_PROPOSAL_JN_PERSON 
  (PROPOSAL_ID)
/





-----------------------------------------------------------------------------
-- KSPR_PROPOSAL_JN_REFERENCE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSPR_PROPOSAL_JN_REFERENCE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSPR_PROPOSAL_JN_REFERENCE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSPR_PROPOSAL_JN_REFERENCE
(
      PROPOSAL_ID VARCHAR2(255) NOT NULL
        , REFERENCE_ID VARCHAR2(255) NOT NULL
    

)
/



CREATE INDEX KSPR_PROPOSAL_JN_REFERENCE_I1 
  ON KSPR_PROPOSAL_JN_REFERENCE 
  (REFERENCE_ID)
/
CREATE INDEX KSPR_PROPOSAL_JN_REFERENCE_I2 
  ON KSPR_PROPOSAL_JN_REFERENCE 
  (PROPOSAL_ID)
/





-----------------------------------------------------------------------------
-- KSPR_PROPOSAL_REFERENCE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSPR_PROPOSAL_REFERENCE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSPR_PROPOSAL_REFERENCE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSPR_PROPOSAL_REFERENCE
(
      REFERENCE_ID VARCHAR2(255)
        , OBJECT_REFERENCE_ID VARCHAR2(255)
        , TYPE VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSPR_PROPOSAL_REFERENCE
    ADD CONSTRAINT KSPR_PROPOSAL_REFERENCEP1
PRIMARY KEY (REFERENCE_ID)
/


CREATE INDEX KSPR_PROPOSAL_REFERENCE_I1 
  ON KSPR_PROPOSAL_REFERENCE 
  (TYPE)
/





-----------------------------------------------------------------------------
-- KSPR_PROPOSAL_REFTYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSPR_PROPOSAL_REFTYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSPR_PROPOSAL_REFTYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSPR_PROPOSAL_REFTYPE
(
      TYPE_KEY VARCHAR2(255)
        , TYPE_DESC VARCHAR2(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSPR_PROPOSAL_REFTYPE
    ADD CONSTRAINT KSPR_PROPOSAL_REFTYPEP1
PRIMARY KEY (TYPE_KEY)
/







-----------------------------------------------------------------------------
-- KSPR_PROPOSAL_REFTYPE_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSPR_PROPOSAL_REFTYPE_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSPR_PROPOSAL_REFTYPE_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSPR_PROPOSAL_REFTYPE_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSPR_PROPOSAL_REFTYPE_ATTR
    ADD CONSTRAINT KSPR_PROPOSAL_REFTYPE_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSPR_PROPOSAL_REFTYPE_ATTR_I1 
  ON KSPR_PROPOSAL_REFTYPE_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSPR_PROPOSAL_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSPR_PROPOSAL_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSPR_PROPOSAL_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSPR_PROPOSAL_TYPE
(
      TYPE_KEY VARCHAR2(255)
        , TYPE_DESC VARCHAR2(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSPR_PROPOSAL_TYPE
    ADD CONSTRAINT KSPR_PROPOSAL_TYPEP1
PRIMARY KEY (TYPE_KEY)
/







-----------------------------------------------------------------------------
-- KSPR_PROPOSAL_TYPE_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSPR_PROPOSAL_TYPE_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSPR_PROPOSAL_TYPE_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSPR_PROPOSAL_TYPE_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSPR_PROPOSAL_TYPE_ATTR
    ADD CONSTRAINT KSPR_PROPOSAL_TYPE_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSPR_PROPOSAL_TYPE_ATTR_I1 
  ON KSPR_PROPOSAL_TYPE_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSPR_RICH_TEXT_T
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSPR_RICH_TEXT_T';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSPR_RICH_TEXT_T CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSPR_RICH_TEXT_T
(
      ID VARCHAR2(255)
        , FORMATTED VARCHAR2(2000)
        , PLAIN VARCHAR2(2000)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSPR_RICH_TEXT_T
    ADD CONSTRAINT KSPR_RICH_TEXT_TP1
PRIMARY KEY (ID)
/







-----------------------------------------------------------------------------
-- KSSC_SUBJ_CD
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSSC_SUBJ_CD';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSSC_SUBJ_CD CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSSC_SUBJ_CD
(
      ID VARCHAR2(255)
        , CREATEID VARCHAR2(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR2(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR NUMBER(19) NOT NULL
        , NAME VARCHAR2(255)
        , STATE VARCHAR2(255)
        , CD VARCHAR2(255)
        , TYPE VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
    
    , CONSTRAINT KSSC_SUBJ_CD_IX1 UNIQUE (CD)

)
/

ALTER TABLE KSSC_SUBJ_CD
    ADD CONSTRAINT KSSC_SUBJ_CDP1
PRIMARY KEY (ID)
/







-----------------------------------------------------------------------------
-- KSSC_SUBJ_CD_JN_ORG
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSSC_SUBJ_CD_JN_ORG';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSSC_SUBJ_CD_JN_ORG CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSSC_SUBJ_CD_JN_ORG
(
      ID VARCHAR2(255)
        , ORG_ID VARCHAR2(255)
        , SUBJ_CD_ID VARCHAR2(255)
        , VER_NBR NUMBER(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , OBJ_ID VARCHAR2(36)
    

)
/

ALTER TABLE KSSC_SUBJ_CD_JN_ORG
    ADD CONSTRAINT KSSC_SUBJ_CD_JN_ORGP1
PRIMARY KEY (ID)
/







-----------------------------------------------------------------------------
-- KSSC_SUBJ_CD_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSSC_SUBJ_CD_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSSC_SUBJ_CD_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSSC_SUBJ_CD_TYPE
(
      TYPE_KEY VARCHAR2(255)
        , TYPE_DESC VARCHAR2(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSSC_SUBJ_CD_TYPE
    ADD CONSTRAINT KSSC_SUBJ_CD_TYPEP1
PRIMARY KEY (TYPE_KEY)
/







-----------------------------------------------------------------------------
-- KSST_NL_USAGE_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSST_NL_USAGE_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSST_NL_USAGE_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSST_NL_USAGE_TYPE
(
      TYPE_KEY VARCHAR2(255)
        , TYPE_DESC VARCHAR2(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSST_NL_USAGE_TYPE
    ADD CONSTRAINT KSST_NL_USAGE_TYPEP1
PRIMARY KEY (TYPE_KEY)
/







-----------------------------------------------------------------------------
-- KSST_OBJECT_SUB_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSST_OBJECT_SUB_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSST_OBJECT_SUB_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSST_OBJECT_SUB_TYPE
(
      TYPE_KEY VARCHAR2(255)
        , TYPE_DESC VARCHAR2(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSST_OBJECT_SUB_TYPE
    ADD CONSTRAINT KSST_OBJECT_SUB_TYPEP1
PRIMARY KEY (TYPE_KEY)
/







-----------------------------------------------------------------------------
-- KSST_OBJECT_SUB_TYPE_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSST_OBJECT_SUB_TYPE_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSST_OBJECT_SUB_TYPE_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSST_OBJECT_SUB_TYPE_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSST_OBJECT_SUB_TYPE_ATTR
    ADD CONSTRAINT KSST_OBJECT_SUB_TYPE_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSST_OBJECT_SUB_TYPE_ATTR_I1 
  ON KSST_OBJECT_SUB_TYPE_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSST_OBJECT_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSST_OBJECT_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSST_OBJECT_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSST_OBJECT_TYPE
(
      TYPE_KEY VARCHAR2(255)
        , TYPE_DESC VARCHAR2(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSST_OBJECT_TYPE
    ADD CONSTRAINT KSST_OBJECT_TYPEP1
PRIMARY KEY (TYPE_KEY)
/







-----------------------------------------------------------------------------
-- KSST_OBJECT_TYPE_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSST_OBJECT_TYPE_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSST_OBJECT_TYPE_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSST_OBJECT_TYPE_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSST_OBJECT_TYPE_ATTR
    ADD CONSTRAINT KSST_OBJECT_TYPE_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSST_OBJECT_TYPE_ATTR_I1 
  ON KSST_OBJECT_TYPE_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSST_OBJ_TYP_JN_OBJ_SUB_TYP
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSST_OBJ_TYP_JN_OBJ_SUB_TYP';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSST_OBJ_TYP_JN_OBJ_SUB_TYP CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSST_OBJ_TYP_JN_OBJ_SUB_TYP
(
      OBJ_TYPE_ID VARCHAR2(255) NOT NULL
        , OBJ_SUB_TYPE_ID VARCHAR2(255) NOT NULL
    
    , CONSTRAINT SYS_C0011792 UNIQUE (OBJ_SUB_TYPE_ID)

)
/



CREATE INDEX KSST_OBJ_TYP_JN_OBJ_SUBTYP_I2 
  ON KSST_OBJ_TYP_JN_OBJ_SUB_TYP 
  (OBJ_TYPE_ID)
/





-----------------------------------------------------------------------------
-- KSST_RCTYP_JN_RCFLDTYP
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSST_RCTYP_JN_RCFLDTYP';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSST_RCTYP_JN_RCFLDTYP CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSST_RCTYP_JN_RCFLDTYP
(
      REQ_COMP_TYPE_ID VARCHAR2(255) NOT NULL
        , REQ_COMP_FIELD_TYPE_ID VARCHAR2(255) NOT NULL
    
    , CONSTRAINT IX1 UNIQUE (REQ_COMP_TYPE_ID, REQ_COMP_FIELD_TYPE_ID)

)
/



CREATE INDEX KSST_RCTYP_JN_RCFLDTYP_I1 
  ON KSST_RCTYP_JN_RCFLDTYP 
  (REQ_COMP_FIELD_TYPE_ID)
/
CREATE INDEX KSST_RCTYP_JN_RCFLDTYP_I2 
  ON KSST_RCTYP_JN_RCFLDTYP 
  (REQ_COMP_TYPE_ID)
/





-----------------------------------------------------------------------------
-- KSST_RC_JN_RC_FIELD
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSST_RC_JN_RC_FIELD';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSST_RC_JN_RC_FIELD CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSST_RC_JN_RC_FIELD
(
      REQ_COM_ID VARCHAR2(255) NOT NULL
        , REQ_COM_FIELD_ID VARCHAR2(255) NOT NULL
    
    , CONSTRAINT SYS_C0011797 UNIQUE (REQ_COM_FIELD_ID)

)
/



CREATE INDEX KSST_RC_JN_RC_FIELD_I1 
  ON KSST_RC_JN_RC_FIELD 
  (REQ_COM_ID)
/





-----------------------------------------------------------------------------
-- KSST_REF_STMT_REL
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSST_REF_STMT_REL';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSST_REF_STMT_REL CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSST_REF_STMT_REL
(
      ID VARCHAR2(255)
        , CREATEID VARCHAR2(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR2(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR NUMBER(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , REF_OBJ_ID VARCHAR2(255)
        , REF_OBJ_TYPE_KEY VARCHAR2(255)
        , ST VARCHAR2(255)
        , REF_STMT_REL_TYPE_ID VARCHAR2(255)
        , STMT_ID VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
    

)
/

ALTER TABLE KSST_REF_STMT_REL
    ADD CONSTRAINT KSST_REF_STMT_RELP1
PRIMARY KEY (ID)
/


CREATE INDEX KSST_REF_STMT_REL_I1 
  ON KSST_REF_STMT_REL 
  (REF_STMT_REL_TYPE_ID)
/
CREATE INDEX KSST_REF_STMT_REL_I2 
  ON KSST_REF_STMT_REL 
  (STMT_ID)
/





-----------------------------------------------------------------------------
-- KSST_REF_STMT_REL_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSST_REF_STMT_REL_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSST_REF_STMT_REL_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSST_REF_STMT_REL_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSST_REF_STMT_REL_ATTR
    ADD CONSTRAINT KSST_REF_STMT_REL_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSST_REF_STMT_REL_ATTR_I1 
  ON KSST_REF_STMT_REL_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSST_REF_STMT_REL_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSST_REF_STMT_REL_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSST_REF_STMT_REL_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSST_REF_STMT_REL_TYPE
(
      TYPE_KEY VARCHAR2(255)
        , TYPE_DESC VARCHAR2(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSST_REF_STMT_REL_TYPE
    ADD CONSTRAINT KSST_REF_STMT_REL_TYPEP1
PRIMARY KEY (TYPE_KEY)
/







-----------------------------------------------------------------------------
-- KSST_REF_STMT_REL_TYPE_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSST_REF_STMT_REL_TYPE_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSST_REF_STMT_REL_TYPE_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSST_REF_STMT_REL_TYPE_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSST_REF_STMT_REL_TYPE_ATTR
    ADD CONSTRAINT KSST_REF_STMT_REL_TYPE_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSST_REF_STMT_REL_TYP_ATTR_I1 
  ON KSST_REF_STMT_REL_TYPE_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSST_REQ_COM
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSST_REQ_COM';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSST_REQ_COM CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSST_REQ_COM
(
      ID VARCHAR2(255)
        , CREATEID VARCHAR2(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR2(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR NUMBER(19) NOT NULL
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , ST VARCHAR2(255)
        , RT_DESCR_ID VARCHAR2(255)
        , REQ_COM_TYPE_ID VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
    

)
/

ALTER TABLE KSST_REQ_COM
    ADD CONSTRAINT KSST_REQ_COMP1
PRIMARY KEY (ID)
/


CREATE INDEX KSST_REQ_COM_I1 
  ON KSST_REQ_COM 
  (REQ_COM_TYPE_ID)
/
CREATE INDEX KSST_REQ_COM_I2 
  ON KSST_REQ_COM 
  (RT_DESCR_ID)
/





-----------------------------------------------------------------------------
-- KSST_REQ_COM_FIELD
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSST_REQ_COM_FIELD';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSST_REQ_COM_FIELD CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSST_REQ_COM_FIELD
(
      ID VARCHAR2(255)
        , REQ_COM_FIELD_TYPE VARCHAR2(255)
        , VALUE VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSST_REQ_COM_FIELD
    ADD CONSTRAINT KSST_REQ_COM_FIELDP1
PRIMARY KEY (ID)
/







-----------------------------------------------------------------------------
-- KSST_REQ_COM_FIELD_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSST_REQ_COM_FIELD_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSST_REQ_COM_FIELD_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSST_REQ_COM_FIELD_TYPE
(
      ID VARCHAR2(255)
        , DATA_TYPE VARCHAR2(255) NOT NULL
        , DESCR VARCHAR2(255) NOT NULL
        , INVALID_CHARS VARCHAR2(255)
        , MAX_LENGTH NUMBER(10)
        , MAX_OCCURS NUMBER(10)
        , MAX_VALUE VARCHAR2(255)
        , MIN_LENGTH NUMBER(10)
        , MIN_OCCURS NUMBER(10)
        , MIN_VALUE VARCHAR2(255)
        , NAME VARCHAR2(255) NOT NULL
        , READ_ONLY NUMBER(1) NOT NULL
        , VALID_CHARS VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSST_REQ_COM_FIELD_TYPE
    ADD CONSTRAINT KSST_REQ_COM_FIELD_TYPEP1
PRIMARY KEY (ID)
/







-----------------------------------------------------------------------------
-- KSST_REQ_COM_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSST_REQ_COM_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSST_REQ_COM_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSST_REQ_COM_TYPE
(
      TYPE_KEY VARCHAR2(255)
        , TYPE_DESC VARCHAR2(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSST_REQ_COM_TYPE
    ADD CONSTRAINT KSST_REQ_COM_TYPEP1
PRIMARY KEY (TYPE_KEY)
/







-----------------------------------------------------------------------------
-- KSST_REQ_COM_TYPE_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSST_REQ_COM_TYPE_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSST_REQ_COM_TYPE_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSST_REQ_COM_TYPE_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSST_REQ_COM_TYPE_ATTR
    ADD CONSTRAINT KSST_REQ_COM_TYPE_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSST_REQ_COM_TYPE_ATTR_I1 
  ON KSST_REQ_COM_TYPE_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSST_REQ_COM_TYPE_NL_TMPL
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSST_REQ_COM_TYPE_NL_TMPL';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSST_REQ_COM_TYPE_NL_TMPL CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSST_REQ_COM_TYPE_NL_TMPL
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , LANGUAGE VARCHAR2(2)
        , NL_USUAGE_TYPE_KEY VARCHAR2(255)
        , TEMPLATE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSST_REQ_COM_TYPE_NL_TMPL
    ADD CONSTRAINT KSST_REQ_COM_TYPE_NL_TMPLP1
PRIMARY KEY (ID)
/


CREATE INDEX KSST_REQ_COM_TYPE_NL_TMPL_I1 
  ON KSST_REQ_COM_TYPE_NL_TMPL 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSST_RICH_TEXT_T
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSST_RICH_TEXT_T';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSST_RICH_TEXT_T CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSST_RICH_TEXT_T
(
      ID VARCHAR2(255)
        , FORMATTED VARCHAR2(2000)
        , PLAIN VARCHAR2(2000)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSST_RICH_TEXT_T
    ADD CONSTRAINT KSST_RICH_TEXT_TP1
PRIMARY KEY (ID)
/







-----------------------------------------------------------------------------
-- KSST_RSTMT_RTYP_JN_OSUB_TYP
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSST_RSTMT_RTYP_JN_OSUB_TYP';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSST_RSTMT_RTYP_JN_OSUB_TYP CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSST_RSTMT_RTYP_JN_OSUB_TYP
(
      REF_STMT_REL_TYPE_ID VARCHAR2(255) NOT NULL
        , OBJ_SUB_TYPE_ID VARCHAR2(255) NOT NULL
    

)
/



CREATE INDEX KSST_RSTMT_RTYP_JN_OSUBTYP_I1 
  ON KSST_RSTMT_RTYP_JN_OSUB_TYP 
  (OBJ_SUB_TYPE_ID)
/
CREATE INDEX KSST_RSTMT_RTYP_JN_OSUBTYP_I2 
  ON KSST_RSTMT_RTYP_JN_OSUB_TYP 
  (REF_STMT_REL_TYPE_ID)
/





-----------------------------------------------------------------------------
-- KSST_RSTMT_RTYP_JN_STMT_TYP
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSST_RSTMT_RTYP_JN_STMT_TYP';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSST_RSTMT_RTYP_JN_STMT_TYP CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSST_RSTMT_RTYP_JN_STMT_TYP
(
      REF_STMT_REL_TYPE_ID VARCHAR2(255) NOT NULL
        , STMT_TYPE_ID VARCHAR2(255) NOT NULL
    

)
/



CREATE INDEX KSST_RSTMT_RTYP_JN_ST_TYP_I1 
  ON KSST_RSTMT_RTYP_JN_STMT_TYP 
  (REF_STMT_REL_TYPE_ID)
/
CREATE INDEX KSST_RSTMT_RTYP_JN_ST_TYP_I2 
  ON KSST_RSTMT_RTYP_JN_STMT_TYP 
  (STMT_TYPE_ID)
/





-----------------------------------------------------------------------------
-- KSST_STMT
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSST_STMT';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSST_STMT CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSST_STMT
(
      ID VARCHAR2(255)
        , CREATEID VARCHAR2(255)
        , CREATETIME TIMESTAMP
        , UPDATEID VARCHAR2(255)
        , UPDATETIME TIMESTAMP
        , VER_NBR NUMBER(19) NOT NULL
        , NAME VARCHAR2(255)
        , OPERATOR VARCHAR2(255)
        , ST VARCHAR2(255)
        , RT_DESCR_ID VARCHAR2(255)
        , STMT_TYPE_ID VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
    

)
/

ALTER TABLE KSST_STMT
    ADD CONSTRAINT KSST_STMTP1
PRIMARY KEY (ID)
/


CREATE INDEX KSST_STMT_I1 
  ON KSST_STMT 
  (STMT_TYPE_ID)
/
CREATE INDEX KSST_STMT_I2 
  ON KSST_STMT 
  (RT_DESCR_ID)
/





-----------------------------------------------------------------------------
-- KSST_STMT_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSST_STMT_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSST_STMT_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSST_STMT_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSST_STMT_ATTR
    ADD CONSTRAINT KSST_STMT_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSST_STMT_ATTR_I1 
  ON KSST_STMT_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSST_STMT_JN_REQ_COM
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSST_STMT_JN_REQ_COM';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSST_STMT_JN_REQ_COM CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSST_STMT_JN_REQ_COM
(
      STMT_ID VARCHAR2(255) NOT NULL
        , REQ_COM_ID VARCHAR2(255) NOT NULL
    

)
/



CREATE INDEX KSST_STMT_JN_REQ_COM_I1 
  ON KSST_STMT_JN_REQ_COM 
  (STMT_ID)
/
CREATE INDEX KSST_STMT_JN_REQ_COM_I2 
  ON KSST_STMT_JN_REQ_COM 
  (REQ_COM_ID)
/





-----------------------------------------------------------------------------
-- KSST_STMT_JN_STMT
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSST_STMT_JN_STMT';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSST_STMT_JN_STMT CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSST_STMT_JN_STMT
(
      STMT_ID VARCHAR2(255) NOT NULL
        , CHLD_STMT_ID VARCHAR2(255) NOT NULL
    
    , CONSTRAINT SYS_C0011839 UNIQUE (CHLD_STMT_ID)

)
/



CREATE INDEX KSST_STMT_JN_STMT_I1 
  ON KSST_STMT_JN_STMT 
  (STMT_ID)
/





-----------------------------------------------------------------------------
-- KSST_STMT_TYPE
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSST_STMT_TYPE';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSST_STMT_TYPE CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSST_STMT_TYPE
(
      TYPE_KEY VARCHAR2(255)
        , TYPE_DESC VARCHAR2(2000)
        , EFF_DT TIMESTAMP
        , EXPIR_DT TIMESTAMP
        , NAME VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSST_STMT_TYPE
    ADD CONSTRAINT KSST_STMT_TYPEP1
PRIMARY KEY (TYPE_KEY)
/







-----------------------------------------------------------------------------
-- KSST_STMT_TYPE_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSST_STMT_TYPE_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSST_STMT_TYPE_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSST_STMT_TYPE_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSST_STMT_TYPE_ATTR
    ADD CONSTRAINT KSST_STMT_TYPE_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSST_STMT_TYPE_ATTR_I1 
  ON KSST_STMT_TYPE_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KSST_STMT_TYP_JN_RC_TYP
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSST_STMT_TYP_JN_RC_TYP';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSST_STMT_TYP_JN_RC_TYP CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSST_STMT_TYP_JN_RC_TYP
(
      ID VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
        , REQ_COM_TYPE_ID VARCHAR2(255)
        , SORT_ORDER NUMBER(10)
        , STMT_TYPE_ID VARCHAR2(255)
    

)
/

ALTER TABLE KSST_STMT_TYP_JN_RC_TYP
    ADD CONSTRAINT KSST_STMT_TYP_JN_RC_TYPP1
PRIMARY KEY (ID)
/


CREATE INDEX KSST_STMT_TYP_JN_RC_TYP_I1 
  ON KSST_STMT_TYP_JN_RC_TYP 
  (REQ_COM_TYPE_ID)
/
CREATE INDEX KSST_STMT_TYP_JN_RC_TYP_I2 
  ON KSST_STMT_TYP_JN_RC_TYP 
  (STMT_TYPE_ID)
/





-----------------------------------------------------------------------------
-- KSST_STMT_TYP_JN_STMT_TYP
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSST_STMT_TYP_JN_STMT_TYP';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSST_STMT_TYP_JN_STMT_TYP CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSST_STMT_TYP_JN_STMT_TYP
(
      ID VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
        , CHLD_STMT_TYPE_ID VARCHAR2(255)
        , SORT_ORDER NUMBER(10)
        , STMT_TYPE_ID VARCHAR2(255)
    

)
/

ALTER TABLE KSST_STMT_TYP_JN_STMT_TYP
    ADD CONSTRAINT KSST_STMT_TYP_JN_STMT_TYPP1
PRIMARY KEY (ID)
/


CREATE INDEX KSST_STMT_TYP_JN_STMT_TYP_I1 
  ON KSST_STMT_TYP_JN_STMT_TYP 
  (CHLD_STMT_TYPE_ID)
/
CREATE INDEX KSST_STMT_TYP_JN_STMT_TYP_I2 
  ON KSST_STMT_TYP_JN_STMT_TYP 
  (STMT_TYPE_ID)
/





-----------------------------------------------------------------------------
-- KSST_USAGE_TYPE_ATTR
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KSST_USAGE_TYPE_ATTR';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KSST_USAGE_TYPE_ATTR CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KSST_USAGE_TYPE_ATTR
(
      ID VARCHAR2(255)
        , ATTR_NAME VARCHAR2(255)
        , ATTR_VALUE VARCHAR2(2000)
        , OWNER VARCHAR2(255)
        , OBJ_ID VARCHAR2(36)
        , VER_NBR NUMBER(19)
    

)
/

ALTER TABLE KSST_USAGE_TYPE_ATTR
    ADD CONSTRAINT KSST_USAGE_TYPE_ATTRP1
PRIMARY KEY (ID)
/


CREATE INDEX KSST_USAGE_TYPE_ATTR_I1 
  ON KSST_USAGE_TYPE_ATTR 
  (OWNER)
/





-----------------------------------------------------------------------------
-- KS_DB_VERSION
-----------------------------------------------------------------------------
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_tables WHERE table_name = 'KS_DB_VERSION';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP TABLE KS_DB_VERSION CASCADE CONSTRAINTS PURGE'; END IF;
END;
/

CREATE TABLE KS_DB_VERSION
(
      VERSION VARCHAR2(255)
        , MODULE_NAME VARCHAR2(255)
        , UPGRADE_TIME TIMESTAMP default SYSDATE
        , BUILD_ID VARCHAR2(255)
        , BUILD_TIMESTAMP VARCHAR2(255)
    

)
/








-- -----------------------------------------------------------------------
-- KRIM_GRP_MBR_V
-- -----------------------------------------------------------------------
CREATE OR REPLACE FORCE VIEW KRIM_GRP_MBR_V AS 
SELECT g.NMSPC_CD
, g.grp_nm
, g.GRP_ID
, p.PRNCPL_NM
, p.PRNCPL_ID
, mg.GRP_NM AS mbr_grp_nm
, mg.GRP_ID AS mbr_grp_id
FROM KRIM_GRP_MBR_T gm
LEFT JOIN krim_grp_t g
ON g.GRP_ID = gm.GRP_ID
LEFT OUTER JOIN krim_grp_t mg
ON mg.GRP_ID = gm.MBR_ID
AND gm.MBR_TYP_CD = 'G'
LEFT OUTER JOIN krim_prncpl_t p
ON p.PRNCPL_ID = gm.MBR_ID
AND gm.MBR_TYP_CD = 'P'
LEFT OUTER JOIN krim_entity_nm_t en
ON en.ENTITY_ID = p.ENTITY_ID
AND en.DFLT_IND = 'Y'
AND en.ACTV_IND = 'Y'
ORDER BY nmspc_cd, grp_nm, prncpl_nm




/

-- -----------------------------------------------------------------------
-- KRIM_GRP_V
-- -----------------------------------------------------------------------
CREATE OR REPLACE FORCE VIEW KRIM_GRP_V AS 
SELECT g.NMSPC_CD
, g.grp_nm
, g.GRP_ID
, t.NM AS grp_typ_nm
, a.NM AS attr_nm
, d.ATTR_VAL AS attr_val
FROM krim_grp_t g
LEFT OUTER JOIN KRIM_GRP_ATTR_DATA_T d
ON d.grp_id = g.GRP_ID
LEFT OUTER JOIN KRIM_ATTR_DEFN_T a
ON a.KIM_ATTR_DEFN_ID = d.KIM_ATTR_DEFN_ID
LEFT OUTER JOIN KRIM_TYP_T t
ON g.KIM_TYP_ID = t.KIM_TYP_ID




/

-- -----------------------------------------------------------------------
-- KRIM_PERM_ATTR_V
-- -----------------------------------------------------------------------
CREATE OR REPLACE FORCE VIEW KRIM_PERM_ATTR_V AS 
SELECT
t.nmspc_cd AS tmpl_nmspc_cd
, t.NM AS tmpl_nm
, t.PERM_TMPL_ID
, p.nmspc_cd AS perm_nmspc_cd
, p.NM AS perm_nm
, p.PERM_ID
, a.NM AS attr_nm
, ad.ATTR_VAL AS attr_val
FROM KRIM_PERM_T p
LEFT JOIN KRIM_PERM_TMPL_T t
ON p.PERM_TMPL_ID = t.PERM_TMPL_ID
LEFT OUTER JOIN KRIM_PERM_ATTR_DATA_T ad
ON p.PERM_ID = ad.perm_id
LEFT OUTER JOIN KRIM_ATTR_DEFN_T a
ON ad.KIM_ATTR_DEFN_ID = a.KIM_ATTR_DEFN_ID
ORDER BY tmpl_nmspc_cd, tmpl_nm, perm_nmspc_cd, perm_id, attr_nm




/

-- -----------------------------------------------------------------------
-- KRIM_PERM_V
-- -----------------------------------------------------------------------
CREATE OR REPLACE FORCE VIEW KRIM_PERM_V AS 
SELECT
t.nmspc_cd AS tmpl_nmspc_cd
, t.NM AS tmpl_nm
, t.PERM_TMPL_ID
, p.nmspc_cd AS perm_nmspc_cd
, p.NM AS perm_nm
, p.PERM_ID
, typ.NM AS perm_typ_nm
, typ.SRVC_NM
FROM KRIM_PERM_T p
INNER JOIN KRIM_PERM_TMPL_T t
ON p.PERM_TMPL_ID = t.PERM_TMPL_ID
LEFT OUTER JOIN KRIM_TYP_T typ
ON t.KIM_TYP_ID = typ.KIM_TYP_ID




/

-- -----------------------------------------------------------------------
-- KRIM_PRNCPL_V
-- -----------------------------------------------------------------------
CREATE OR REPLACE FORCE VIEW KRIM_PRNCPL_V AS 
SELECT
p.PRNCPL_ID
,p.PRNCPL_NM
,en.FIRST_NM
,en.LAST_NM
,ea.AFLTN_TYP_CD
,ea.CAMPUS_CD
,eei.EMP_STAT_CD
,eei.EMP_TYP_CD
FROM krim_prncpl_t p
LEFT OUTER JOIN krim_entity_emp_info_t eei
ON eei.ENTITY_ID = p.ENTITY_ID
LEFT OUTER JOIN krim_entity_afltn_t ea
ON ea.ENTITY_ID = p.ENTITY_ID
LEFT OUTER JOIN krim_entity_nm_t en
ON p.ENTITY_ID = en.ENTITY_ID
AND 'Y' = en.DFLT_IND




/

-- -----------------------------------------------------------------------
-- KRIM_ROLE_GRP_V
-- -----------------------------------------------------------------------
CREATE OR REPLACE FORCE VIEW KRIM_ROLE_GRP_V AS 
SELECT r.NMSPC_CD
, r.ROLE_NM
, r.role_id
, g.NMSPC_CD AS grp_nmspc_cd
, g.GRP_NM
, rm.ROLE_MBR_ID
, a.NM AS attr_nm
, d.ATTR_VAL AS attr_val
FROM KRIM_ROLE_MBR_T rm
LEFT JOIN KRIM_ROLE_T r
ON r.ROLE_ID = rm.ROLE_ID
LEFT JOIN KRIM_GRP_T g
ON g.GRP_ID = rm.MBR_ID
LEFT OUTER JOIN KRIM_ROLE_MBR_ATTR_DATA_T d
ON d.role_mbr_id = rm.ROLE_MBR_ID
LEFT OUTER JOIN KRIM_ATTR_DEFN_T a
ON a.KIM_ATTR_DEFN_ID = d.KIM_ATTR_DEFN_ID
WHERE rm.MBR_TYP_CD = 'G'
ORDER BY nmspc_cd, role_nm, grp_nmspc_cd, grp_nm, role_mbr_id, attr_nm




/

-- -----------------------------------------------------------------------
-- KRIM_ROLE_PERM_V
-- -----------------------------------------------------------------------
CREATE OR REPLACE FORCE VIEW KRIM_ROLE_PERM_V AS 
SELECT r.NMSPC_CD
, r.ROLE_NM
, r.role_id
, pt.NMSPC_CD AS tmpl_nmspc_cd
, pt.NM AS tmpl_nm
, pt.PERM_TMPL_ID
, p.NMSPC_CD AS perm_nmpsc_cd
, p.NM AS perm_nm
, p.PERM_ID
, a.NM AS attr_nm
, ad.ATTR_VAL AS attr_val
FROM KRIM_PERM_T p
LEFT JOIN KRIM_PERM_TMPL_T pt
ON p.PERM_TMPL_ID = pt.PERM_TMPL_ID
LEFT OUTER JOIN KRIM_PERM_ATTR_DATA_T ad
ON p.PERM_ID = ad.perm_id
LEFT OUTER JOIN KRIM_ATTR_DEFN_T a
ON ad.KIM_ATTR_DEFN_ID = a.KIM_ATTR_DEFN_ID
LEFT OUTER JOIN KRIM_ROLE_PERM_T rp
ON rp.PERM_ID = p.PERM_ID
LEFT OUTER JOIN KRIM_ROLE_T r
ON rp.ROLE_ID = r.ROLE_ID
ORDER BY NMSPC_CD, role_nm, tmpl_nmspc_cd, tmpl_nm, perm_id, attr_nm




/

-- -----------------------------------------------------------------------
-- KRIM_ROLE_PRNCPL_V
-- -----------------------------------------------------------------------
CREATE OR REPLACE FORCE VIEW KRIM_ROLE_PRNCPL_V AS 
SELECT r.NMSPC_CD
, r.ROLE_NM
, r.ROLE_ID
, p.PRNCPL_NM
, p.PRNCPL_ID
, en.FIRST_NM
, en.LAST_NM
, rm.ROLE_MBR_ID
, ad.NM AS attr_nm
, rmad.ATTR_VAL AS attr_val
FROM KRIM_ROLE_T r
LEFT OUTER JOIN KRIM_ROLE_MBR_T rm
ON r.ROLE_ID = rm.ROLE_ID
LEFT OUTER JOIN KRIM_ROLE_MBR_ATTR_DATA_T rmad
ON rm.ROLE_MBR_ID = rmad.role_mbr_id
LEFT OUTER JOIN KRIM_ATTR_DEFN_T ad
ON rmad.KIM_ATTR_DEFN_ID = ad.KIM_ATTR_DEFN_ID
LEFT OUTER JOIN KRIM_PRNCPL_T p
ON rm.MBR_ID = p.PRNCPL_ID
AND rm.mbr_typ_cd = 'P'
LEFT OUTER JOIN KRIM_ENTITY_NM_T en
ON p.ENTITY_ID = en.ENTITY_ID
WHERE (en.DFLT_IND = 'Y')
ORDER BY nmspc_cd, role_nm, prncpl_nm, rm.ROLE_MBR_ID, attr_nm




/

-- -----------------------------------------------------------------------
-- KRIM_ROLE_ROLE_V
-- -----------------------------------------------------------------------
CREATE OR REPLACE FORCE VIEW KRIM_ROLE_ROLE_V AS 
SELECT r.NMSPC_CD
, r.ROLE_NM
, r.role_id
, mr.NMSPC_CD AS mbr_role_nmspc_cd
, mr.role_NM AS mbr_role_nm
, mr.role_id AS mbr_role_id
, rm.role_mbr_id
, a.NM AS attr_nm
, d.ATTR_VAL AS attr_val
FROM KRIM_ROLE_MBR_T rm
LEFT JOIN KRIM_ROLE_T r
ON r.ROLE_ID = rm.ROLE_ID
LEFT JOIN KRIM_role_T mr
ON mr.role_ID = rm.MBR_ID
LEFT OUTER JOIN KRIM_ROLE_MBR_ATTR_DATA_T d
ON d.role_mbr_id = rm.ROLE_MBR_ID
LEFT OUTER JOIN KRIM_ATTR_DEFN_T a
ON a.KIM_ATTR_DEFN_ID = d.KIM_ATTR_DEFN_ID
WHERE rm.MBR_TYP_CD = 'R'
ORDER BY nmspc_cd, role_nm, mbr_role_nmspc_cd, mbr_role_nm, role_mbr_id, attr_nm




/

-- -----------------------------------------------------------------------
-- KRIM_ROLE_V
-- -----------------------------------------------------------------------
CREATE OR REPLACE FORCE VIEW KRIM_ROLE_V AS 
SELECT r.NMSPC_CD
, r.ROLE_NM
, r.ROLE_ID
, t.nm AS role_typ_nm
, t.SRVC_NM
, t.KIM_TYP_ID
FROM KRIM_ROLE_T r
, KRIM_TYP_T t
WHERE t.KIM_TYP_ID = r.KIM_TYP_ID
AND r.ACTV_IND = 'Y'
ORDER BY nmspc_cd
, role_nm




/

-- -----------------------------------------------------------------------
-- KRIM_RSP_ATTR_V
-- -----------------------------------------------------------------------
CREATE OR REPLACE FORCE VIEW KRIM_RSP_ATTR_V AS 
SELECT
krim_typ_t.NM AS responsibility_type_name
, KRIM_rsp_TMPL_T.NM AS rsp_TEMPLATE_NAME
, KRIM_rsp_T.nmspc_cd AS rsp_namespace_code
, KRIM_rsp_T.NM AS rsp_NAME
, krim_rsp_t.RSP_ID AS rsp_id
, KRIM_ATTR_DEFN_T.NM AS attribute_name
, KRIM_rsp_ATTR_DATA_T.ATTR_VAL AS attribute_value
FROM KRIM_rsp_T KRIM_rsp_T
INNER JOIN KRIM_rsp_ATTR_DATA_T KRIM_rsp_ATTR_DATA_T
ON KRIM_rsp_T.rsp_ID = KRIM_rsp_ATTR_DATA_T.rsp_id
INNER JOIN KRIM_ATTR_DEFN_T KRIM_ATTR_DEFN_T
ON KRIM_rsp_ATTR_DATA_T.KIM_ATTR_DEFN_ID = KRIM_ATTR_DEFN_T.KIM_ATTR_DEFN_ID
INNER JOIN KRIM_rsp_TMPL_T KRIM_rsp_TMPL_T
ON KRIM_rsp_T.rsp_TMPL_ID = KRIM_rsp_TMPL_T.rsp_TMPL_ID
INNER JOIN KRIM_TYP_T KRIM_TYP_T
ON KRIM_rsp_TMPL_T.KIM_TYP_ID = KRIM_TYP_T.KIM_TYP_ID
ORDER BY rsp_TEMPLATE_NAME, rsp_NAME, attribute_name




/

-- -----------------------------------------------------------------------
-- KRIM_RSP_ROLE_ACTN_V
-- -----------------------------------------------------------------------
CREATE OR REPLACE FORCE VIEW KRIM_RSP_ROLE_ACTN_V AS 
select
rsp.nmspc_cd as rsp_nmspc_cd
, rsp.rsp_id
, r.NMSPC_CD
, r.ROLE_NM
, rr.ROLE_ID
, rm.MBR_ID
, rm.MBR_TYP_CD
, rm.ROLE_MBR_ID
, actn.ACTN_TYP_CD
, actn.ACTN_PLCY_CD
, actn.FRC_ACTN
, actn.PRIORITY_NBR
from krim_rsp_t rsp
left join krim_rsp_tmpl_t rspt
on rsp.rsp_tmpl_id = rspt.rsp_tmpl_id
left outer join krim_role_rsp_t rr
on rr.rsp_id = rsp.rsp_id
left outer join KRIM_ROLE_MBR_T rm
ON rm.ROLE_ID = rr.ROLE_ID
left outer join KRIM_ROLE_RSP_ACTN_T actn
ON actn.ROLE_RSP_ID = rr.ROLE_RSP_ID
AND (actn.ROLE_MBR_ID = rm.ROLE_MBR_ID OR actn.ROLE_MBR_ID = '*')
left outer join krim_role_t r
on rr.role_id = r.role_id
order by rsp_nmspc_cd
, rsp_id
, role_id
, role_mbr_id




/

-- -----------------------------------------------------------------------
-- KRIM_RSP_ROLE_V
-- -----------------------------------------------------------------------
CREATE OR REPLACE FORCE VIEW KRIM_RSP_ROLE_V AS 
select
rspt.nmspc_cd as rsp_tmpl_nmspc_cd
, rspt.nm as rsp_tmpl_nm
, rsp.nmspc_cd as rsp_nmspc_cd
, rsp.nm as rsp_nm
, rsp.rsp_id
, a.nm as attr_nm
, d.attr_val
, r.NMSPC_CD
, r.ROLE_NM
, rr.ROLE_ID
from krim_rsp_t rsp
left join krim_rsp_tmpl_t rspt
on rsp.rsp_tmpl_id = rspt.rsp_tmpl_id
left outer join krim_rsp_attr_data_t d
on rsp.rsp_id = d.rsp_id
left outer join krim_attr_defn_t a
on d.kim_attr_defn_id = a.kim_attr_defn_id
left outer join krim_role_rsp_t rr
on rr.rsp_id = rsp.rsp_id
left outer join krim_role_t r
on rr.role_id = r.role_id
order by rsp_tmpl_nmspc_cd, rsp_tmpl_nm, rsp_nmspc_cd, rsp_nm, rsp_id, attr_nm, attr_val




/
DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KREN_CHNL_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KREN_CHNL_S'; END IF;
END;
/

CREATE SEQUENCE KREN_CHNL_S INCREMENT BY 1 START WITH 1000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KREN_CHNL_SUBSCRP_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KREN_CHNL_SUBSCRP_S'; END IF;
END;
/

CREATE SEQUENCE KREN_CHNL_SUBSCRP_S INCREMENT BY 1 START WITH 1020 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KREN_CNTNT_TYP_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KREN_CNTNT_TYP_S'; END IF;
END;
/

CREATE SEQUENCE KREN_CNTNT_TYP_S INCREMENT BY 1 START WITH 1000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KREN_MSG_DELIV_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KREN_MSG_DELIV_S'; END IF;
END;
/

CREATE SEQUENCE KREN_MSG_DELIV_S INCREMENT BY 1 START WITH 1000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KREN_MSG_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KREN_MSG_S'; END IF;
END;
/

CREATE SEQUENCE KREN_MSG_S INCREMENT BY 1 START WITH 1000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KREN_NTFCTN_MSG_DELIV_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KREN_NTFCTN_MSG_DELIV_S'; END IF;
END;
/

CREATE SEQUENCE KREN_NTFCTN_MSG_DELIV_S INCREMENT BY 1 START WITH 1000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KREN_NTFCTN_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KREN_NTFCTN_S'; END IF;
END;
/

CREATE SEQUENCE KREN_NTFCTN_S INCREMENT BY 1 START WITH 1000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KREN_PRIO_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KREN_PRIO_S'; END IF;
END;
/

CREATE SEQUENCE KREN_PRIO_S INCREMENT BY 1 START WITH 1000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KREN_PRODCR_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KREN_PRODCR_S'; END IF;
END;
/

CREATE SEQUENCE KREN_PRODCR_S INCREMENT BY 1 START WITH 1000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KREN_RECIP_DELIV_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KREN_RECIP_DELIV_S'; END IF;
END;
/

CREATE SEQUENCE KREN_RECIP_DELIV_S INCREMENT BY 1 START WITH 1000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KREN_RECIP_LIST_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KREN_RECIP_LIST_S'; END IF;
END;
/

CREATE SEQUENCE KREN_RECIP_LIST_S INCREMENT BY 1 START WITH 1000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KREN_RECIP_PREF_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KREN_RECIP_PREF_S'; END IF;
END;
/

CREATE SEQUENCE KREN_RECIP_PREF_S INCREMENT BY 1 START WITH 1000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KREN_RECIP_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KREN_RECIP_S'; END IF;
END;
/

CREATE SEQUENCE KREN_RECIP_S INCREMENT BY 1 START WITH 1000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KREN_RVWER_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KREN_RVWER_S'; END IF;
END;
/

CREATE SEQUENCE KREN_RVWER_S INCREMENT BY 1 START WITH 1000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KREN_SNDR_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KREN_SNDR_S'; END IF;
END;
/

CREATE SEQUENCE KREN_SNDR_S INCREMENT BY 1 START WITH 1000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KREW_ACTN_ITM_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KREW_ACTN_ITM_S'; END IF;
END;
/

CREATE SEQUENCE KREW_ACTN_ITM_S INCREMENT BY 1 START WITH 10320 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KREW_ACTN_LIST_OPTN_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KREW_ACTN_LIST_OPTN_S'; END IF;
END;
/

CREATE SEQUENCE KREW_ACTN_LIST_OPTN_S INCREMENT BY 1 START WITH 1373 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KREW_ACTN_RQST_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KREW_ACTN_RQST_S'; END IF;
END;
/

CREATE SEQUENCE KREW_ACTN_RQST_S INCREMENT BY 1 START WITH 2465 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KREW_ACTN_TKN_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KREW_ACTN_TKN_S'; END IF;
END;
/

CREATE SEQUENCE KREW_ACTN_TKN_S INCREMENT BY 1 START WITH 2389 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KREW_DOC_HDR_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KREW_DOC_HDR_S'; END IF;
END;
/

CREATE SEQUENCE KREW_DOC_HDR_S INCREMENT BY 1 START WITH 3115 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KREW_DOC_LNK_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KREW_DOC_LNK_S'; END IF;
END;
/

CREATE SEQUENCE KREW_DOC_LNK_S INCREMENT BY 1 START WITH 2000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KREW_DOC_NTE_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KREW_DOC_NTE_S'; END IF;
END;
/

CREATE SEQUENCE KREW_DOC_NTE_S INCREMENT BY 1 START WITH 2020 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KREW_DOC_TYP_ATTR_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KREW_DOC_TYP_ATTR_S'; END IF;
END;
/

CREATE SEQUENCE KREW_DOC_TYP_ATTR_S INCREMENT BY 1 START WITH 2016 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KREW_EDL_FLD_DMP_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KREW_EDL_FLD_DMP_S'; END IF;
END;
/

CREATE SEQUENCE KREW_EDL_FLD_DMP_S INCREMENT BY 1 START WITH 5000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KREW_EDL_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KREW_EDL_S'; END IF;
END;
/

CREATE SEQUENCE KREW_EDL_S INCREMENT BY 1 START WITH 2020 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KREW_HLP_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KREW_HLP_S'; END IF;
END;
/

CREATE SEQUENCE KREW_HLP_S INCREMENT BY 1 START WITH 100 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KREW_OUT_BOX_ITM_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KREW_OUT_BOX_ITM_S'; END IF;
END;
/

CREATE SEQUENCE KREW_OUT_BOX_ITM_S INCREMENT BY 1 START WITH 10051 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KREW_RIA_DOCTYPE_MAP_ID_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KREW_RIA_DOCTYPE_MAP_ID_S'; END IF;
END;
/

CREATE SEQUENCE KREW_RIA_DOCTYPE_MAP_ID_S INCREMENT BY 1 START WITH 1000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KREW_RSP_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KREW_RSP_S'; END IF;
END;
/

CREATE SEQUENCE KREW_RSP_S INCREMENT BY 1 START WITH 2065 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KREW_RTE_NODE_CFG_PARM_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KREW_RTE_NODE_CFG_PARM_S'; END IF;
END;
/

CREATE SEQUENCE KREW_RTE_NODE_CFG_PARM_S INCREMENT BY 1 START WITH 3363 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KREW_RTE_NODE_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KREW_RTE_NODE_S'; END IF;
END;
/

CREATE SEQUENCE KREW_RTE_NODE_S INCREMENT BY 1 START WITH 3317 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KREW_RTE_TMPL_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KREW_RTE_TMPL_S'; END IF;
END;
/

CREATE SEQUENCE KREW_RTE_TMPL_S INCREMENT BY 1 START WITH 1645 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KREW_RULE_EXPR_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KREW_RULE_EXPR_S'; END IF;
END;
/

CREATE SEQUENCE KREW_RULE_EXPR_S INCREMENT BY 1 START WITH 2002 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KREW_RULE_TMPL_OPTN_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KREW_RULE_TMPL_OPTN_S'; END IF;
END;
/

CREATE SEQUENCE KREW_RULE_TMPL_OPTN_S INCREMENT BY 1 START WITH 2020 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KREW_SRCH_ATTR_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KREW_SRCH_ATTR_S'; END IF;
END;
/

CREATE SEQUENCE KREW_SRCH_ATTR_S INCREMENT BY 1 START WITH 2188 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KREW_USR_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KREW_USR_S'; END IF;
END;
/

CREATE SEQUENCE KREW_USR_S INCREMENT BY 1 START WITH 100000000000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KRIM_ATTR_DATA_ID_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KRIM_ATTR_DATA_ID_S'; END IF;
END;
/

CREATE SEQUENCE KRIM_ATTR_DATA_ID_S INCREMENT BY 1 START WITH 10012 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KRIM_ATTR_DEFN_ID_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KRIM_ATTR_DEFN_ID_S'; END IF;
END;
/

CREATE SEQUENCE KRIM_ATTR_DEFN_ID_S INCREMENT BY 1 START WITH 10000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KRIM_DLGN_ID_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KRIM_DLGN_ID_S'; END IF;
END;
/

CREATE SEQUENCE KRIM_DLGN_ID_S INCREMENT BY 1 START WITH 10000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KRIM_DLGN_MBR_ID_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KRIM_DLGN_MBR_ID_S'; END IF;
END;
/

CREATE SEQUENCE KRIM_DLGN_MBR_ID_S INCREMENT BY 1 START WITH 10000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KRIM_ENTITY_ADDR_ID_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KRIM_ENTITY_ADDR_ID_S'; END IF;
END;
/

CREATE SEQUENCE KRIM_ENTITY_ADDR_ID_S INCREMENT BY 1 START WITH 10000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KRIM_ENTITY_AFLTN_ID_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KRIM_ENTITY_AFLTN_ID_S'; END IF;
END;
/

CREATE SEQUENCE KRIM_ENTITY_AFLTN_ID_S INCREMENT BY 1 START WITH 10011 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KRIM_ENTITY_CTZNSHP_ID_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KRIM_ENTITY_CTZNSHP_ID_S'; END IF;
END;
/

CREATE SEQUENCE KRIM_ENTITY_CTZNSHP_ID_S INCREMENT BY 1 START WITH 10000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KRIM_ENTITY_EMAIL_ID_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KRIM_ENTITY_EMAIL_ID_S'; END IF;
END;
/

CREATE SEQUENCE KRIM_ENTITY_EMAIL_ID_S INCREMENT BY 1 START WITH 10000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KRIM_ENTITY_EMP_ID_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KRIM_ENTITY_EMP_ID_S'; END IF;
END;
/

CREATE SEQUENCE KRIM_ENTITY_EMP_ID_S INCREMENT BY 1 START WITH 10011 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KRIM_ENTITY_ETHNIC_ID_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KRIM_ENTITY_ETHNIC_ID_S'; END IF;
END;
/

CREATE SEQUENCE KRIM_ENTITY_ETHNIC_ID_S INCREMENT BY 1 START WITH 10000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KRIM_ENTITY_EXT_ID_ID_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KRIM_ENTITY_EXT_ID_ID_S'; END IF;
END;
/

CREATE SEQUENCE KRIM_ENTITY_EXT_ID_ID_S INCREMENT BY 1 START WITH 10000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KRIM_ENTITY_ID_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KRIM_ENTITY_ID_S'; END IF;
END;
/

CREATE SEQUENCE KRIM_ENTITY_ID_S INCREMENT BY 1 START WITH 10008 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KRIM_ENTITY_NM_ID_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KRIM_ENTITY_NM_ID_S'; END IF;
END;
/

CREATE SEQUENCE KRIM_ENTITY_NM_ID_S INCREMENT BY 1 START WITH 10008 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KRIM_ENTITY_PHONE_ID_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KRIM_ENTITY_PHONE_ID_S'; END IF;
END;
/

CREATE SEQUENCE KRIM_ENTITY_PHONE_ID_S INCREMENT BY 1 START WITH 10000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KRIM_ENTITY_RESIDENCY_ID_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KRIM_ENTITY_RESIDENCY_ID_S'; END IF;
END;
/

CREATE SEQUENCE KRIM_ENTITY_RESIDENCY_ID_S INCREMENT BY 1 START WITH 10000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KRIM_ENTITY_VISA_ID_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KRIM_ENTITY_VISA_ID_S'; END IF;
END;
/

CREATE SEQUENCE KRIM_ENTITY_VISA_ID_S INCREMENT BY 1 START WITH 10000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KRIM_GRP_ATTR_DATA_ID_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KRIM_GRP_ATTR_DATA_ID_S'; END IF;
END;
/

CREATE SEQUENCE KRIM_GRP_ATTR_DATA_ID_S INCREMENT BY 1 START WITH 10000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KRIM_GRP_ID_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KRIM_GRP_ID_S'; END IF;
END;
/

CREATE SEQUENCE KRIM_GRP_ID_S INCREMENT BY 1 START WITH 10000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KRIM_GRP_MBR_ID_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KRIM_GRP_MBR_ID_S'; END IF;
END;
/

CREATE SEQUENCE KRIM_GRP_MBR_ID_S INCREMENT BY 1 START WITH 10000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KRIM_PERM_ID_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KRIM_PERM_ID_S'; END IF;
END;
/

CREATE SEQUENCE KRIM_PERM_ID_S INCREMENT BY 1 START WITH 10002 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KRIM_PERM_RQRD_ATTR_ID_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KRIM_PERM_RQRD_ATTR_ID_S'; END IF;
END;
/

CREATE SEQUENCE KRIM_PERM_RQRD_ATTR_ID_S INCREMENT BY 1 START WITH 10000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KRIM_PERM_TMPL_ID_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KRIM_PERM_TMPL_ID_S'; END IF;
END;
/

CREATE SEQUENCE KRIM_PERM_TMPL_ID_S INCREMENT BY 1 START WITH 10000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KRIM_PRNCPL_ID_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KRIM_PRNCPL_ID_S'; END IF;
END;
/

CREATE SEQUENCE KRIM_PRNCPL_ID_S INCREMENT BY 1 START WITH 10000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KRIM_ROLE_ID_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KRIM_ROLE_ID_S'; END IF;
END;
/

CREATE SEQUENCE KRIM_ROLE_ID_S INCREMENT BY 1 START WITH 10000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KRIM_ROLE_MBR_ID_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KRIM_ROLE_MBR_ID_S'; END IF;
END;
/

CREATE SEQUENCE KRIM_ROLE_MBR_ID_S INCREMENT BY 1 START WITH 10028 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KRIM_ROLE_PERM_ID_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KRIM_ROLE_PERM_ID_S'; END IF;
END;
/

CREATE SEQUENCE KRIM_ROLE_PERM_ID_S INCREMENT BY 1 START WITH 1015 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KRIM_ROLE_RSP_ACTN_ID_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KRIM_ROLE_RSP_ACTN_ID_S'; END IF;
END;
/

CREATE SEQUENCE KRIM_ROLE_RSP_ACTN_ID_S INCREMENT BY 1 START WITH 10000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KRIM_ROLE_RSP_ID_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KRIM_ROLE_RSP_ID_S'; END IF;
END;
/

CREATE SEQUENCE KRIM_ROLE_RSP_ID_S INCREMENT BY 1 START WITH 10000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KRIM_RSP_ID_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KRIM_RSP_ID_S'; END IF;
END;
/

CREATE SEQUENCE KRIM_RSP_ID_S INCREMENT BY 1 START WITH 10000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KRIM_RSP_RQRD_ATTR_ID_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KRIM_RSP_RQRD_ATTR_ID_S'; END IF;
END;
/

CREATE SEQUENCE KRIM_RSP_RQRD_ATTR_ID_S INCREMENT BY 1 START WITH 10000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KRIM_RSP_TMPL_ID_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KRIM_RSP_TMPL_ID_S'; END IF;
END;
/

CREATE SEQUENCE KRIM_RSP_TMPL_ID_S INCREMENT BY 1 START WITH 10000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KRIM_TYP_ATTR_ID_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KRIM_TYP_ATTR_ID_S'; END IF;
END;
/

CREATE SEQUENCE KRIM_TYP_ATTR_ID_S INCREMENT BY 1 START WITH 10000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KRIM_TYP_ID_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KRIM_TYP_ID_S'; END IF;
END;
/

CREATE SEQUENCE KRIM_TYP_ID_S INCREMENT BY 1 START WITH 10000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KRNS_DOC_TYP_ATTR_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KRNS_DOC_TYP_ATTR_S'; END IF;
END;
/

CREATE SEQUENCE KRNS_DOC_TYP_ATTR_S INCREMENT BY 1 START WITH 1000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KRNS_LOCK_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KRNS_LOCK_S'; END IF;
END;
/

CREATE SEQUENCE KRNS_LOCK_S INCREMENT BY 1 START WITH 2000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KRNS_LOOKUP_RSLT_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KRNS_LOOKUP_RSLT_S'; END IF;
END;
/

CREATE SEQUENCE KRNS_LOOKUP_RSLT_S INCREMENT BY 1 START WITH 2000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KRNS_MAINT_LOCK_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KRNS_MAINT_LOCK_S'; END IF;
END;
/

CREATE SEQUENCE KRNS_MAINT_LOCK_S INCREMENT BY 1 START WITH 2020 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KRNS_NTE_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KRNS_NTE_S'; END IF;
END;
/

CREATE SEQUENCE KRNS_NTE_S INCREMENT BY 1 START WITH 2020 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KRSB_BAM_PARM_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KRSB_BAM_PARM_S'; END IF;
END;
/

CREATE SEQUENCE KRSB_BAM_PARM_S INCREMENT BY 1 START WITH 2000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KRSB_BAM_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KRSB_BAM_S'; END IF;
END;
/

CREATE SEQUENCE KRSB_BAM_S INCREMENT BY 1 START WITH 2000 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KRSB_FLT_SVC_DEF_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KRSB_FLT_SVC_DEF_S'; END IF;
END;
/

CREATE SEQUENCE KRSB_FLT_SVC_DEF_S INCREMENT BY 1 START WITH 1325 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KRSB_MSG_QUE_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KRSB_MSG_QUE_S'; END IF;
END;
/

CREATE SEQUENCE KRSB_MSG_QUE_S INCREMENT BY 1 START WITH 2781 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

DECLARE temp NUMBER;
BEGIN
	SELECT COUNT(*) INTO temp FROM user_sequences WHERE sequence_name = 'KRSB_SVC_DEF_S';
	IF temp > 0 THEN EXECUTE IMMEDIATE 'DROP SEQUENCE KRSB_SVC_DEF_S'; END IF;
END;
/

CREATE SEQUENCE KRSB_SVC_DEF_S INCREMENT BY 1 START WITH 1441 NOMAXVALUE NOCYCLE NOCACHE ORDER
/

